"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * debugController.ts
 * Contains the debug endpoints.
 */
const express = __importStar(require("express"));
const got_1 = __importDefault(require("got"));
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const mem_1 = __importDefault(require("mem"));
const urlLib = __importStar(require("url"));
const config_1 = __importDefault(require("../config"));
const token_1 = require("../models/token");
const logger_1 = __importDefault(require("../utils/logger"));
const config = config_1.default.getInstance();
const router = express.Router();
const getMetadata = mem_1.default(() => got_1.default(config.oAuth.metadataUrl)
    .then((result) => JSON.parse(result.body)), {
    maxAge: config.oAuth.metadataCacheMaxAge * 1000,
});
const getUrlOrigin = (urlString) => {
    const urlObject = urlLib.parse(urlString);
    return `${urlObject.protocol}//${urlObject.host}`;
};
const logDebug = (log) => logger_1.default('DEBUG', log);
router.get('/debug', (req, res) => {
    logDebug(`${req.path}: Render debug start page`);
    res.render('debug/start', {
        returnTo: config.debug.returnTo,
        returnToParameter: config.login.parameters.returnTo,
        action: '/auth/',
    });
});
router.get('/debug/result', async (req, res) => {
    logDebug(`${req.path}: Render debug result page`);
    const sessionToken = req.cookies[config.session.cookies.token];
    if (!sessionToken) {
        res.status(400).render('error', {
            error: 'No session token',
            error_description: 'No session token was found in the cookies.',
        });
        return;
    }
    const decodedToken = jsonwebtoken_1.default.decode(sessionToken, { complete: true });
    if (!decodedToken || !token_1.Validators.isJWTToken(decodedToken)) {
        res.status(400).render('error', {
            error: 'Invalid decoded token',
        });
        return;
    }
    const { exp } = decodedToken.payload;
    const tte = exp - (Date.now() / 1000) - 60; // Time to expire
    // Retrieves OIDC provider metadata and renders the result
    if (config.oAuth.provider === "azure-v1" /* AZURE_V1 */) {
        const metadata = await getMetadata();
        res.render('debug/result', {
            appTokenName: config.session.cookies.token,
            appTokenValue: sessionToken,
            postLogoutReturnTo: config.debug.postLogoutReturnTo,
            postLogoutReturnToParameter: config.logout.parameters.postLogoutReturnTo,
            action: '/auth/logout',
            checkSessionIFrame: metadata.check_session_iframe,
            sessionState: req.cookies[config.session.cookies.sessionState],
            clientId: config.oAuth.clientId,
            providerOrigin: metadata.check_session_iframe
                ? getUrlOrigin(metadata.check_session_iframe)
                : null,
        });
    }
    else {
        res.render('debug/result', {
            appTokenName: config.session.cookies.token,
            appTokenValue: req.cookies[config.session.cookies.token],
            postLogoutReturnTo: config.debug.postLogoutReturnTo,
            postLogoutReturnToParameter: config.logout.parameters.postLogoutReturnTo,
            action: '/auth/logout',
            autoRefreshAction: `/auth/?${config.login.parameters.returnTo}=/wfgen/auth/blank&silent=true`,
            autoRefreshTte: tte * 1000,
        });
    }
});
router.get('/debug/logout/result', (req, res) => {
    logDebug(`${req.path}: Render debug logout result page`);
    res.render('debug/logoutResult');
});
exports.default = router;
