"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * keysController.js
 * Contains handlers for keys related endpoints.
 */
const changeCase = __importStar(require("change-case"));
const cors_1 = __importDefault(require("cors"));
const express = __importStar(require("express"));
const got_1 = __importDefault(require("got"));
const mem_1 = __importDefault(require("mem"));
const config_1 = __importDefault(require("../config"));
const logger_1 = __importDefault(require("../utils/logger"));
const config = config_1.default.getInstance();
const router = express.Router();
const memGot = mem_1.default(got_1.default, { maxAge: config.oAuth.metadataCacheMaxAge * 1000 });
const getDataFromUrl = (url) => memGot(url, {})
    .then((res) => JSON.parse(res.body.toString()));
const logDebug = (message) => logger_1.default('DEBUG', message);
const logError = (message) => logger_1.default('ERROR', message);
const responseError = (error, res, status) => res.status(status).json(error);
const getJsonError = (error) => ({
    error: changeCase.snakeCase(error.constructor.name),
    error_description: error.message,
});
const responseErrorJson = (error, res, status) => responseError(getJsonError(error), res, status);
const metadataURLForTenantID = (tenantId) => `https://login.microsoftonline.com/${tenantId}/.well-known/openid-configuration`;
class InvalidRequest extends Error {
}
router.get('/azuread', cors_1.default(), async (req, res) => {
    const tenantId = req.query.tenant_id;
    const getLogMessage = (message) => `${req.path} : ${message}`;
    const res400 = (error) => responseErrorJson(error, res, 400);
    logDebug(getLogMessage(`Received request with tenant id: ${tenantId}`));
    if (!tenantId || typeof tenantId !== 'string') {
        const error = new InvalidRequest('No tenant id provided.');
        logError(getLogMessage(error.message));
        res400(error);
        return;
    }
    const metadataUrl = metadataURLForTenantID(tenantId);
    let keys;
    try {
        const metadata = await getDataFromUrl(metadataUrl);
        keys = await getDataFromUrl(metadata.jwks_uri);
    }
    catch (err) {
        const error = new Error(`Could not get the keys. Err: ${err}`);
        logError(getLogMessage(error.message));
        res400(error);
        return;
    }
    res.status(200).json(keys);
});
exports.default = router;
