"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable max-classes-per-file */
/**
 * tokenController.ts
 * Contains the definition of the token endpoints.
 */
const changeCase = __importStar(require("change-case"));
const express = __importStar(require("express"));
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const config_1 = __importDefault(require("../config"));
const token_1 = require("../models/token");
const logger_1 = __importDefault(require("../utils/logger"));
const router = express.Router();
const config = config_1.default.getInstance();
class InvalidToken extends Error {
}
class InvalidRedirectUri extends Error {
}
const getJsonError = (error) => ({
    error: changeCase.snakeCase(error.constructor.name),
    error_description: error.message,
});
const responseError = (error, res) => res.status(400).json(error);
const logDebug = (message) => logger_1.default('DEBUG', message);
const logError = (message) => logger_1.default('ERROR', message);
const getSessionTokenExpiration = (configOptions) => Math
    .floor((Date.now() + (configOptions.session.token.mobileMaxAge * 1000)) / 1000);
router.get('/session_token', async (req, res) => {
    const accessToken = token_1.getBearerToken(req);
    const resError = (error) => responseError(getJsonError(error), res);
    const resCookie = (name, value) => res.cookie(name, value, { httpOnly: true });
    const redirectUri = req.query.redirect_uri;
    let claims;
    if (!accessToken) {
        logError('Token is missing or malformed');
        resError(new InvalidToken('Token is missing or malformed'));
        return;
    }
    logDebug(`Verifiying the token claims for: ${accessToken}`);
    try {
        claims = await token_1.getTokenClaims(req, accessToken, config.oAuth.webviewTokenValidation);
    }
    catch (err) {
        logError(`An error occured ${err}`);
        resError(new InvalidToken('Token is invalid'));
        return;
    }
    const { payload } = claims;
    const username = payload[config.oAuth.accessTokenUsernameClaim];
    const exp = getSessionTokenExpiration(config);
    let sessionToken;
    logDebug(`Found username: ${username} for token: ${accessToken}`);
    try {
        sessionToken = jsonwebtoken_1.default.sign({
            sub: username,
            iss: config.session.token.issuer,
            aud: config.session.token.audience,
            exp,
        }, config.session.token.signingSecret);
    }
    catch (err) {
        logError(`Could not sign a new session token. Error: ${err}`);
        resError(new InvalidToken('Token is invalid'));
        return;
    }
    logDebug(`New session token generated: ${sessionToken}`);
    if (redirectUri) {
        if (!process.env.ApplicationUrl || !redirectUri.startsWith(process.env.ApplicationUrl)) {
            logError(`Redirect uri: ${redirectUri} does not start with ApplicationUrl: ${process.env.ApplicationUrl}`);
            resError(new InvalidRedirectUri('The redirect uri provided is not part of WorkflowGen\'s origin.'));
            return;
        }
        logDebug(`Redirecting user to url: ${redirectUri}...`);
        resCookie(config.session.cookies.token, sessionToken);
        /* istanbul ignore else */
        if (process.env.NODE_ENV === 'test') {
            res.status(200).send(redirectUri);
        }
        else {
            res.redirect(redirectUri);
        }
        return;
    }
    resCookie(config.session.cookies.token, sessionToken);
    res.status(200).send();
});
exports.default = router;
