"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * graphql.ts
 * Contains the GraphQL API endpoints.
 */
const express_graphql_1 = __importDefault(require("express-graphql"));
const graphql_upload_1 = require("graphql-upload");
const schemaPrinter = __importStar(require("graphql/utilities/schemaPrinter"));
const express = __importStar(require("express"));
const schema_1 = require("../models/schema");
const workflowservice_1 = __importDefault(require("../services/workflow/workflowservice"));
const logger_1 = require("../utils/logger");
const context_1 = require("../models/auth/context");
const loaders_1 = require("../models/loaders");
const config_1 = __importDefault(require("../config"));
const config = config_1.default.getInstance();
const router = express.Router();
const schema = schema_1.createSchema(config.graphql); // Schema creation
const workflowService = process.env.NODE_ENV === 'test'
    ? require('../../test/stub').WorkflowService()
    : new workflowservice_1.default(config.workflowService);
// Print Schema endpoint
router.use('/schema', (req, res) => {
    res.set('Content-Type', 'text/plain');
    res.send(schemaPrinter.printSchema(schema));
});
// Print Introspection Schema endpoint
router.use('/ischema', (req, res) => {
    res.set('Content-Type', 'text/plain');
    res.send(schemaPrinter.printIntrospectionSchema(schema));
});
// File download endpoint
router.get('/workflow/data/files/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const args = {
        id: req.params.id,
        response: {
            set: (data, callback) => {
                res.set(data.name, data.value);
                callback();
            },
            write: (data, callback) => {
                res.write(data);
                callback();
            }
        }
    };
    if (req.query.onBehalfOf) {
        args.onBehalfOf = req.query.onBehalfOf;
    }
    try {
        var fileSize = yield workflowService.invoke('sendWorkflowDataFile', context_1.getWorkflowContext(req), args);
    }
    catch (err) {
        const error = err;
        logger_1.logger('ERROR', `Request ${req.uuid} sendWorkflowDataFile operation error: ${error.message}`);
        res.status(error.statusCode).json({ error: error.message });
        return;
    }
    logger_1.logger('INFO', `Request ${req.uuid} sendWorkflowDataFile: file sent: id: ${args.id} size: ${fileSize} bytes`);
    res.end();
}));
// Process definition download endpoint
router.get('/processes/:id/xpdl', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const args = {
        id: req.params.id,
        response: {
            set: (data, callback) => {
                res.set(data.name, data.value);
                callback();
            },
            write: (data, callback) => {
                res.write(data);
                callback();
            }
        }
    };
    try {
        var fileSize = yield workflowService.invoke('sendProcessDefinition', context_1.getWorkflowContext(req), args);
    }
    catch (err) {
        const error = err;
        logger_1.logger('ERROR', `Request ${req.uuid} sendProcessDefinition operation error: ${error.message}`);
        res.status(error.statusCode).json({ error: error.message });
        return;
    }
    logger_1.logger('INFO', `Request ${req.uuid} sendProcessDefinition: file sent: id: ${args.id} size: ${fileSize} bytes`);
    res.end();
}));
// Global list definition download endpoint
router.get('/globallists/:id/definition', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const args = {
        id: req.params.id,
        response: {
            set: (data, callback) => {
                res.set(data.name, data.value);
                callback();
            },
            write: (data, callback) => {
                res.write(data);
                callback();
            }
        }
    };
    try {
        var fileSize = yield workflowService.invoke('sendGlobalListDefinition', context_1.getWorkflowContext(req), args);
    }
    catch (err) {
        const error = err;
        logger_1.logger('ERROR', `Request ${req.uuid} sendGlobalListDefinition operation error: ${error.message}`);
        res.status(error.statusCode).json({ error: error.message });
        return;
    }
    logger_1.logger('INFO', `Request ${req.uuid} sendGlobalListDefinition: file sent: id: ${args.id} size: ${fileSize} bytes`);
    res.end();
}));
// GraphQL endpoint
router.use(graphql_upload_1.graphqlUploadExpress({
    maxFileSize: config.workflowService.maxInputFileSize * 1024,
    maxFiles: config.graphql.maxUploadFiles
}), express_graphql_1.default((request) => {
    const startTime = Date.now();
    /* istanbul ignore next */
    request.isUpload = request.headers['content-type']
        ? request.headers['content-type'].toLowerCase().indexOf('multipart/form-data') > -1
        : false;
    request.workflow = {
        service: workflowService,
        context: context_1.getWorkflowContext(request)
    };
    request.loaders = loaders_1.createLoaders(config.loaders, request);
    request.resolverCount = 0;
    request.logTimeoutError = true;
    logger_1.logger('INFO', 'new request ' + request.uuid + ' by ' + request.workflow.context.authUserName);
    request.incrementResolverCount = function () {
        const runTime = Date.now() - startTime;
        if (runTime > config.graphql.queryTimeout) {
            if (request.logTimeoutError) {
                logger_1.logger('ERROR', `Request ${request.uuid} query execution timeout`);
            }
            request.logTimeoutError = false;
            throw new Error('Query execution has timeout. Field resolution aborted.');
        }
        this.resolverCount++;
    };
    return !config.graphql.debugEnabled
        ? {
            schema,
            context: request,
            graphiql: config.graphql.graphiqlEnabled
        }
        : {
            schema,
            context: request,
            graphiql: config.graphql.graphiqlEnabled,
            customFormatErrorFn: error => ({
                message: error.message,
                locations: error.locations,
                stack: error.stack
            }),
            extensions: () => ({
                requestId: request.uuid,
                runTime: Date.now() - startTime,
                resolverCount: request.resolverCount,
                operationCount: request.workflow.context.operationCount,
                operationErrorCount: request.workflow.context.operationErrorCount
            })
        };
}));
exports.default = router;
