"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class AccessTokenRecipentValidatorFactory {
    static getDefault() {
        return new AzureV1AccessTokenRecipentValidator()
            .setNext(new MSIdentityV2AccessTokenRecipentValidator())
            .setNext(new OktaAccessTokenRecipentValidator())
            .setNext(new Auth0AccessTokenRecipentValidator())
            .setNext(new ADFSAccessTokenRecipentValidator());
    }
}
exports.AccessTokenRecipentValidatorFactory = AccessTokenRecipentValidatorFactory;
class AccessTokenRecipentValidator {
    constructor(provider) {
        this.provider = provider;
    }
    setProvider(provider) {
        this.provider = provider;
    }
    setNext(validator) {
        let lastLogger = this;
        while (typeof lastLogger.next !== 'undefined') {
            lastLogger = lastLogger.next;
        }
        lastLogger.next = validator;
        return this;
    }
    validate(tokenClaims, config, isClientCredentials = false) {
        var _a, _b;
        if (this.provider === config.oAuth.accessTokenProvider) {
            return this.validateAudience(tokenClaims, config, isClientCredentials);
        }
        return _b = (_a = this.next) === null || _a === void 0 ? void 0 : _a.validate(tokenClaims, config, isClientCredentials), (_b !== null && _b !== void 0 ? _b : false);
    }
}
exports.AccessTokenRecipentValidator = AccessTokenRecipentValidator;
class AzureV1AccessTokenRecipentValidator extends AccessTokenRecipentValidator {
    constructor() {
        super("azure-v1" /* AZURE_V1 */);
    }
    validateAudience(tokenClaims, config, isClientCredentials = false) {
        var _a;
        if (isClientCredentials &&
            (config.oAuth.graphqlAppRole ||
                config.oAuth.graphqlScope)) {
            return false;
        }
        else if (!isClientCredentials &&
            config.oAuth.graphqlScope &&
            !((_a = tokenClaims.payload.scp) === null || _a === void 0 ? void 0 : _a.includes(config.oAuth.graphqlScope))) {
            return false;
        }
        return true;
    }
}
class ADFSAccessTokenRecipentValidator extends AzureV1AccessTokenRecipentValidator {
    constructor() {
        super();
        this.setProvider("adfs" /* ADFS */);
    }
}
class MSIdentityV2AccessTokenRecipentValidator extends AccessTokenRecipentValidator {
    constructor() {
        super("ms-identity-v2" /* MS_IDENTITY_V2 */);
    }
    validateAudience(tokenClaims, config, isClientCredentials = false) {
        var _a, _b;
        if (isClientCredentials &&
            config.oAuth.graphqlAppRole &&
            !((_a = tokenClaims.payload.roles) === null || _a === void 0 ? void 0 : _a.includes(config.oAuth.graphqlAppRole))) {
            return false;
        }
        else if (!isClientCredentials &&
            config.oAuth.graphqlScope &&
            !((_b = tokenClaims.payload.scp) === null || _b === void 0 ? void 0 : _b.includes(config.oAuth.graphqlScope))) {
            return false;
        }
        return true;
    }
}
class OktaAccessTokenRecipentValidator extends AccessTokenRecipentValidator {
    constructor() {
        super("okta" /* OKTA */);
    }
    validateAudience(tokenClaims, config, isClientCredentials = false) {
        var _a;
        if (config.oAuth.graphqlScope &&
            !((_a = tokenClaims.payload.scp) === null || _a === void 0 ? void 0 : _a.includes(config.oAuth.graphqlScope))) {
            return false;
        }
        return true;
    }
}
class Auth0AccessTokenRecipentValidator extends AccessTokenRecipentValidator {
    constructor() {
        super("auth0" /* AUTH0 */);
    }
    validateAudience(tokenClaims, config, isClientCredentials = false) {
        var _a;
        if (config.oAuth.graphqlScope &&
            !((_a = tokenClaims.payload.scope) === null || _a === void 0 ? void 0 : _a.includes(config.oAuth.graphqlScope))) {
            return false;
        }
        return true;
    }
}
