"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const dataloader_1 = __importDefault(require("dataloader"));
const user_1 = require("./user");
const category_1 = require("./category");
const workflownode_1 = require("./workflownode");
/**
 * Creates Data Loaders.
 * @param context A Context.
 * @return An object containing data loaders by category of GraphQL objects.
 */
function createLoaders(config, context) {
    return {
        operations: new dataloader_1.default(keys => workflownode_1.getWorkflowNodesByOperation(context, keys), {
            cacheKeyFn: cacheKey,
            cache: config.cacheEnabled,
            batch: config.batchEnabled,
            maxBatchSize: config.maxBatchSize
        }),
        users: new dataloader_1.default(keys => workflownode_1.getBatchWorkflowNodes('getUsers', context, keys), {
            cache: config.cacheEnabled,
            batch: config.batchEnabled,
            maxBatchSize: config.maxBatchSize
        }),
        usersByUserName: new dataloader_1.default(keys => user_1.getBatchUsersByUserName(context, keys), {
            cache: config.cacheEnabled,
            batch: config.batchEnabled,
            maxBatchSize: config.maxBatchSize
        }),
        processes: new dataloader_1.default(keys => workflownode_1.getBatchWorkflowNodes('getProcesses', context, keys), {
            cache: config.cacheEnabled,
            batch: config.batchEnabled,
            maxBatchSize: config.maxBatchSize
        }),
        categories: new dataloader_1.default(keys => workflownode_1.getBatchWorkflowNodes('getCategories', context, keys), {
            cache: config.cacheEnabled,
            batch: config.batchEnabled,
            maxBatchSize: config.maxBatchSize
        }),
        categoryByName: new dataloader_1.default(keys => category_1.getBatchCategoryByName(context, keys), {
            cache: config.cacheEnabled,
            batch: config.batchEnabled,
            maxBatchSize: config.maxBatchSize
        }),
        participants: new dataloader_1.default(keys => workflownode_1.getBatchWorkflowNodes('getParticipants', context, keys), {
            cache: config.cacheEnabled,
            batch: config.batchEnabled,
            maxBatchSize: config.maxBatchSize
        })
    };
}
exports.createLoaders = createLoaders;
/**
 * Clear all Loaders.
 * @param loaders Loaders
 */
function clearAllLoaders(loaders) {
    Object.keys(loaders).map(key => loaders[key].clearAll());
}
exports.clearAllLoaders = clearAllLoaders;
/**
 * Creates a cache key.
 * @param key A key.
 * @return A serialized representation of the key.
 */
function cacheKey(key) {
    return typeof key === 'object'
        ? JSON.stringify(key)
        : String(key);
}
