"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Get workflow operations by operation.
 * @param context A context.
 * @param keys An Array of keys.
 * @return A promise resolved with an Array of values.
 */
function getWorkflowNodesByOperation(context, keys) {
    return __awaiter(this, void 0, void 0, function* () {
        return Promise.all(keys.map((key) => context.workflow.service.invoke(key.operation, context.workflow.context, key.args)));
    });
}
exports.getWorkflowNodesByOperation = getWorkflowNodesByOperation;
/**
 * Get workflow nodes by id.
 * @param operation The name of the operation to call in the facade.
 * @param context A context.
 * @param keys An Array of keys.
 * @return A promise resolved with an Array of values.
 */
function getBatchWorkflowNodes(operation, context, keys) {
    return __awaiter(this, void 0, void 0, function* () {
        const result = yield context.workflow.service.invoke(operation, context.workflow.context, {
            ids: keys,
            isBatch: true
        });
        return keys.map(key => {
            const node = result.items.find(item => item.id === key);
            if (!node) {
                throw new Error('The node does not exist.');
            }
            return node;
        });
    });
}
exports.getBatchWorkflowNodes = getBatchWorkflowNodes;
