"use strict";
/**
 * action.ts
 * GraphQL resolvers
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = {
    Action: {
        request(action, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getRequest',
                args: Object.extend({}, {
                    id: action.requestId,
                    userId: action.userId || undefined,
                    onBehalfOf: action.onBehalfOf || undefined
                })
            });
        },
        activity(action, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getActivity',
                args: Object.extend(args, {
                    id: action.activityId,
                    userId: action.userId
                })
            });
        },
        childRequest(action, args, context) {
            if (action.childRequestId === null) {
                return null;
            }
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getRequest',
                args: Object.extend({}, {
                    id: action.childRequestId,
                    userId: action.userId || undefined,
                    onBehalfOf: action.onBehalfOf || undefined
                })
            });
        },
        initiator(action, args, context) {
            if (action.initiatorId === null) {
                return null;
            }
            context.incrementResolverCount();
            return context.loaders.users.load(action.initiatorId);
        },
        assignee(action, args, context) {
            if (action.assigneeId === null) {
                return null;
            }
            context.incrementResolverCount();
            return context.loaders.users.load(action.assigneeId);
        },
        delegatedAssignee(action, args, context) {
            if (action.delegatedAssigneeId === null) {
                return null;
            }
            context.incrementResolverCount();
            return context.loaders.users.load(action.delegatedAssigneeId);
        },
        assignor(action, args, context) {
            if (action.assignorId === null) {
                return null;
            }
            context.incrementResolverCount();
            return context.loaders.users.load(action.assignorId);
        },
        abortedBy(action, args, context) {
            if (action.abortedById === null) {
                return null;
            }
            context.incrementResolverCount();
            return context.loaders.users.load(action.abortedById);
        },
        dataset(action, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getActionDataset',
                args: Object.extend(args, {
                    actionId: action.id,
                    userId: action.userId || undefined,
                    onBehalfOf: action.onBehalfOf || undefined
                })
            });
        },
        canAssign(action, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'canAssignAction',
                args: Object.extend(args, {
                    id: action.id,
                    userId: action.userId || undefined,
                    onBehalfOf: action.onBehalfOf || undefined
                })
            });
        },
        canAssignUser(action, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'canAssignUserToAction',
                args: Object.extend(args, {
                    id: action.id,
                    userId: action.userId || undefined,
                    onBehalfOf: action.onBehalfOf || undefined
                })
            });
        },
        canCancel(action, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'canCancelAction',
                args: Object.extend(args, {
                    id: action.id,
                    userId: action.userId || undefined,
                    onBehalfOf: action.onBehalfOf || undefined
                })
            });
        },
        canCancelAssignment(action, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'canCancelActionAssignment',
                args: Object.extend(args, {
                    id: action.id,
                    userId: action.userId || undefined,
                    onBehalfOf: action.onBehalfOf || undefined
                })
            });
        },
        assignableUsers(action, args, context) {
            return __awaiter(this, void 0, void 0, function* () {
                context.incrementResolverCount();
                const result = yield context.loaders.operations.load({
                    operation: 'getActionAssignableUsers',
                    args: Object.extend(args, {
                        id: action.id,
                        userId: action.userId || undefined,
                        onBehalfOf: action.onBehalfOf || undefined
                    })
                });
                result.items = result.items.map((id) => {
                    context.incrementResolverCount();
                    return context.loaders.users.load(id);
                });
                return result;
            });
        },
        canComplete(action, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'canCompleteAction',
                args: Object.extend(args, {
                    id: action.id,
                    userId: action.userId || undefined,
                    onBehalfOf: action.onBehalfOf || undefined
                })
            });
        },
        parameters(action, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getActionParameters',
                args: Object.extend(args, {
                    actionId: action.id,
                    userId: action.userId || undefined,
                    onBehalfOf: action.onBehalfOf || undefined
                })
            });
        },
        interactiveParameters(action, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getActionInteractiveParameters',
                args: Object.extend(args, {
                    actionId: action.id,
                    userId: action.userId || undefined,
                    onBehalfOf: action.onBehalfOf || undefined
                })
            });
        }
    }
};
