"use strict";
/**
 * activity.ts
 * GraphQL resolvers
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = {
    Activity: {
        process(activity, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getProcess',
                args: Object.extend(args, {
                    id: activity.processId,
                    userId: activity.userId || undefined,
                    onBehalfOf: activity.onBehalfOf || undefined
                })
            });
        },
        subProcess(activity, args, context) {
            if (activity.subProcessId === null) {
                return null;
            }
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getProcess',
                args: Object.extend(args, {
                    id: activity.subProcessId,
                    userId: activity.userId || undefined,
                    onBehalfOf: activity.onBehalfOf || undefined
                })
            });
        },
        participant(activity, args, context) {
            if (activity.participantId === null) {
                return null;
            }
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getParticipant',
                args: Object.extend(args, {
                    id: activity.participantId,
                    userId: activity.userId || undefined,
                    onBehalfOf: activity.onBehalfOf || undefined
                })
            });
        },
        application(activity, args, context) {
            context.incrementResolverCount();
            if (activity.applicationId === null) {
                return null;
            }
            return context.loaders.operations.load({
                operation: 'getApplication',
                args: Object.extend(args, {
                    id: activity.applicationId,
                    userId: activity.userId || undefined
                })
            });
        },
        hasQuickApproval(activity, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'hasQuickApprovalActivity',
                args: Object.extend(args, {
                    id: activity.id,
                    userId: activity.userId || undefined,
                    onBehalfOf: activity.onBehalfOf || undefined
                })
            });
        },
        isForm(activity, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'isFormActivity',
                args: Object.extend(args, {
                    id: activity.id,
                    userId: activity.userId || undefined,
                    onBehalfOf: activity.onBehalfOf || undefined
                })
            });
        },
        quickApprovalParameters(activity, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getActivityQuickApprovalParameters',
                args: Object.extend(args, {
                    id: activity.id,
                    userId: activity.userId || undefined,
                    onBehalfOf: activity.onBehalfOf || undefined
                })
            });
        }
    }
};
