"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * mutation.ts
 * GraphQL resolvers
 */
const loaders_1 = require("../loaders");
const upload_1 = require("../upload");
function invokeWorkflowService(serviceOperation, root, args, context, clearResolvers = true) {
    context.incrementResolverCount();
    clearResolvers && loaders_1.clearAllLoaders(context.loaders);
    return context.workflow.service.invoke(serviceOperation, context.workflow.context, args);
}
function invokeMutation(mutationName, root, args, context, clearLoaders = true) {
    context.incrementResolverCount();
    clearLoaders && loaders_1.clearAllLoaders(context.loaders);
    return upload_1.invokeMutation(mutationName, context, args);
}
exports.default = {
    Mutation: {
        createRequest: (root, args, context) => invokeMutation('createRequest', root, args, context),
        cancelRequest: (root, args, context) => invokeWorkflowService('cancelRequest', root, args, context),
        completeAction: (root, args, context) => invokeMutation('completeAction', root, args, context),
        completeFormAction: (root, args, context) => invokeMutation('completeFormAction', root, args, context),
        assignAction: (root, args, context) => invokeWorkflowService('assignAction', root, args, context),
        cancelActionAssignment: (root, args, context) => invokeWorkflowService('cancelActionAssignment', root, args, context),
        cancelAction: (root, args, context) => invokeWorkflowService('cancelAction', root, args, context),
        cancelRequestActionsByName: (root, args, context) => invokeWorkflowService('cancelRequestActionsByName', root, args, context),
        startInteractiveAction: (root, args, context) => invokeMutation('startInteractiveAction', root, args, context),
        createDelegation: (root, args, context) => invokeWorkflowService('createDelegation', root, args, context),
        deleteDelegation: (root, args, context) => invokeWorkflowService('deleteDelegation', root, args, context, false),
        updateDelegation: (root, args, context) => invokeWorkflowService('updateDelegation', root, args, context),
        addComment: (root, args, context) => invokeWorkflowService('addComment', root, args, context),
        updateComment: (root, args, context) => invokeWorkflowService('updateComment', root, args, context),
        removeComment: (root, args, context) => invokeWorkflowService('removeComment', root, args, context),
        updateRequestDataset: (root, args, context) => invokeMutation('updateRequestDataset', root, args, context),
        createFavorite: (root, args, context) => invokeWorkflowService('createFavorite', root, args, context),
        updateFavorite: (root, args, context) => invokeWorkflowService('updateFavorite', root, args, context),
        deleteFavorite: (root, args, context) => invokeWorkflowService('deleteFavorite', root, args, context),
        createUser: (root, args, context) => invokeWorkflowService('createUser', root, args, context),
        updateUser: (root, args, context) => invokeWorkflowService('updateUser', root, args, context),
        updateViewerPreferences: (root, args, context) => invokeWorkflowService('updateViewerPreferences', root, args, context),
        deleteUser: (root, args, context) => invokeWorkflowService('deleteUser', root, args, context),
        createGroup: (root, args, context) => invokeWorkflowService('createGroup', root, args, context),
        updateGroup: (root, args, context) => invokeWorkflowService('updateGroup', root, args, context),
        deleteGroup: (root, args, context) => invokeWorkflowService('deleteGroup', root, args, context),
        addUsersToGroup: (root, args, context) => invokeWorkflowService('addUsersToGroup', root, args, context),
        removeUsersFromGroup: (root, args, context) => invokeWorkflowService('removeUsersFromGroup', root, args, context),
        addGroupsToUser: (root, args, context) => invokeWorkflowService('addGroupsToUser', root, args, context),
        removeGroupsFromUser: (root, args, context) => invokeWorkflowService('removeGroupsFromUser', root, args, context),
        deleteRequest: (root, args, context) => invokeWorkflowService('deleteRequest', root, args, context),
        createApplication: (root, args, context) => invokeWorkflowService('createApplication', root, args, context),
        updateApplication: (root, args, context) => invokeWorkflowService('updateApplication', root, args, context),
        deleteApplication: (root, args, context) => invokeWorkflowService('deleteApplication', root, args, context),
        addApplicationParameter: (root, args, context) => invokeWorkflowService('addApplicationParameter', root, args, context),
        removeApplicationParameter: (root, args, context) => invokeWorkflowService('removeApplicationParameter', root, args, context),
        createCategory: (root, args, context) => invokeWorkflowService('createCategory', root, args, context),
        updateCategory: (root, args, context) => invokeWorkflowService('updateCategory', root, args, context),
        deleteCategory: (root, args, context) => invokeWorkflowService('deleteCategory', root, args, context),
        createProcessFolder: (root, args, context) => invokeWorkflowService('createProcessFolder', root, args, context),
        updateProcessFolder: (root, args, context) => invokeWorkflowService('updateProcessFolder', root, args, context),
        deleteProcessFolder: (root, args, context) => invokeWorkflowService('deleteProcessFolder', root, args, context),
        createProcess: (root, args, context) => invokeWorkflowService('createProcess', root, args, context),
        updateProcess: (root, args, context) => invokeWorkflowService('updateProcess', root, args, context),
        deleteProcess: (root, args, context) => invokeWorkflowService('deleteProcess', root, args, context),
        createProcessFromXpdl: (root, args, context) => invokeMutation('createProcessFromXpdl', root, args, context),
        updateProcessFromXpdl: (root, args, context) => invokeMutation('updateProcessFromXpdl', root, args, context),
        createGlobalParticipant: (root, args, context) => invokeWorkflowService('createGlobalParticipant', root, args, context),
        updateGlobalParticipant: (root, args, context) => invokeWorkflowService('updateGlobalParticipant', root, args, context),
        deleteGlobalParticipant: (root, args, context) => invokeWorkflowService('deleteGlobalParticipant', root, args, context),
        addProcessParticipantProfile: (root, args, context) => invokeWorkflowService('addProcessParticipantProfile', root, args, context),
        updateProcessParticipantProfile: (root, args, context) => invokeWorkflowService('updateProcessParticipantProfile', root, args, context),
        removeProcessParticipantProfile: (root, args, context) => invokeWorkflowService('removeProcessParticipantProfile', root, args, context),
        createLocalProcessParticipant: (root, args, context) => invokeWorkflowService('createLocalProcessParticipant', root, args, context),
        updateLocalProcessParticipant: (root, args, context) => invokeWorkflowService('updateLocalProcessParticipant', root, args, context),
        deleteLocalProcessParticipant: (root, args, context) => invokeWorkflowService('deleteLocalProcessParticipant', root, args, context),
        createGlobalList: (root, args, context) => invokeWorkflowService('createGlobalList', root, args, context),
        updateGlobalList: (root, args, context) => invokeWorkflowService('updateGlobalList', root, args, context),
        deleteGlobalList: (root, args, context) => invokeWorkflowService('deleteGlobalList', root, args, context),
        createGlobalListFromXmlDefinition: (root, args, context) => invokeMutation('createGlobalListFromXmlDefinition', root, args, context),
        updateGlobalListFromXmlDefinition: (root, args, context) => invokeMutation('updateGlobalListFromXmlDefinition', root, args, context),
        registerViewerPushNotificationToken: (root, args, context) => invokeMutation('registerViewerPushNotificationToken', root, args, context),
        unregisterViewerPushNotificationToken: (root, args, context) => invokeMutation('unregisterViewerPushNotificationToken', root, args, context)
    }
};
