"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * participant.ts
 * GraphQL resolvers
 */
const graphql_relay_1 = require("graphql-relay");
exports.default = {
    Participant: {
        __resolveType: (participant, context, info) => info.schema.getType(graphql_relay_1.fromGlobalId(participant.id).type)
    },
    LocalProcessParticipant: {
        process(localProcessParticipant, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getProcess',
                args: Object.extend(args, {
                    id: localProcessParticipant.processId,
                    userId: localProcessParticipant.userId || undefined,
                    onBehalfOf: localProcessParticipant.onBehalfOf || undefined
                })
            });
        },
        users(localProcessParticipant, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getLocalProcessParticipantUserAssociations',
                args: Object.assign(args, {
                    participantId: localProcessParticipant.id,
                    userId: localProcessParticipant.userId || undefined
                })
            });
        },
        coordinators(localProcessParticipant, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getLocalProcessParticipantCoordinatorAssociations',
                args: Object.assign(args, {
                    participantId: localProcessParticipant.id,
                    userId: localProcessParticipant.userId || undefined
                })
            });
        },
        groups(localProcessParticipant, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getLocalProcessParticipantGroupAssociations',
                args: Object.assign(args, {
                    participantId: localProcessParticipant.id,
                    userId: localProcessParticipant.userId || undefined
                })
            });
        },
        directories(localProcessParticipant, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getLocalProcessParticipantDirectoryAssociations',
                args: Object.assign(args, {
                    participantId: localProcessParticipant.id,
                    userId: localProcessParticipant.userId || undefined
                })
            });
        }
    },
    GlobalParticipant: {
        users(globalParticipant, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getGlobalParticipantUserAssociations',
                args: Object.assign(args, {
                    participantId: globalParticipant.id,
                    userId: globalParticipant.userId || undefined
                })
            });
        },
        coordinators(globalParticipant, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getGlobalParticipantCoordinatorAssociations',
                args: Object.assign(args, {
                    participantId: globalParticipant.id,
                    userId: globalParticipant.userId || undefined
                })
            });
        },
        groups(globalParticipant, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getGlobalParticipantGroupAssociations',
                args: Object.assign(args, {
                    participantId: globalParticipant.id,
                    userId: globalParticipant.userId || undefined
                })
            });
        },
        directories(globalParticipant, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getGlobalParticipantDirectoryAssociations',
                args: Object.assign(args, {
                    participantId: globalParticipant.id,
                    userId: globalParticipant.userId || undefined
                })
            });
        }
    }
};
