"use strict";
/**
 * process.ts
 * GraphQL resolvers
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = {
    Process: {
        dataset(proc, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getProcessDataset',
                args: Object.extend(args, {
                    processId: proc.id,
                    userId: proc.userId || undefined,
                    onBehalfOf: proc.onBehalfOf || undefined
                })
            });
        },
        updatedBy(proc, args, context) {
            context.incrementResolverCount();
            return context.loaders.users.load(proc.updatedById);
        },
        activities(proc, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getActivities',
                args: Object.extend(args, {
                    processId: proc.id,
                    userId: proc.userId || undefined,
                    onBehalfOf: proc.onBehalfOf || undefined
                })
            });
        },
        categories(proc, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getCategories',
                args: Object.extend(args, {
                    filter: Object.extend(args.filter || {}, { processId: proc.id }),
                    userId: proc.userId || undefined,
                    onBehalfOf: proc.onBehalfOf || undefined
                })
            });
        },
        participants(proc, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getProcessParticipants',
                args: Object.extend(args, {
                    processId: proc.id,
                    userId: proc.userId || undefined,
                    onBehalfOf: proc.onBehalfOf || undefined
                })
            });
        },
        participantProfiles(proc, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getProcessParticipantProfiles',
                args: Object.extend(args, {
                    processId: proc.id,
                    userId: proc.userId || undefined,
                    onBehalfOf: proc.onBehalfOf || undefined
                })
            });
        },
        canCreateRequest(proc, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'canCreateRequest',
                args: Object.extend(args, {
                    id: proc.id,
                    userId: proc.userId || undefined,
                    onBehalfOf: proc.onBehalfOf || undefined
                })
            });
        },
        hasGraphicalViewAccess(proc, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'hasGraphicalViewAccess',
                args: Object.extend(args, {
                    id: proc.id,
                    userId: proc.userId || undefined,
                    onBehalfOf: proc.onBehalfOf || undefined
                })
            });
        },
        folder(proc, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getProcessFolder',
                args: Object.extend(args, {
                    id: proc.folderId,
                    userId: proc.userId || undefined
                })
            });
        }
    }
};
