"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * query.ts
 * GraphQL resolvers
 */
const graphql_relay_1 = require("graphql-relay");
function getKeyForGlobalId(id, root, args, context) {
    context.incrementResolverCount();
    switch (graphql_relay_1.fromGlobalId(id).type) {
        case 'Request':
            return context.loaders.operations.load({ operation: 'getRequest', args });
        case 'Action':
            return context.loaders.operations.load({ operation: 'getAction', args });
        case 'View':
            return context.loaders.operations.load({ operation: 'getView', args });
        case 'User':
            return context.loaders.users.load(id);
        case 'Process':
            return !args.onBehalfOf
                ? context.loaders.processes.load(id)
                : context.loaders.operations.load({ operation: 'getProcess', args });
        case 'ProcessFolder':
            return context.loaders.operations.load({ operation: 'getProcessFolder', args });
        case 'Activity':
            return context.loaders.operations.load({ operation: 'getActivity', args });
        case 'Category':
            return !args.onBehalfOf
                ? context.loaders.categories.load(id)
                : context.loaders.operations.load({ operation: 'getCategory', args });
        case 'GlobalParticipant':
            return !args.onBehalfOf
                ? context.loaders.participants.load(id)
                : context.loaders.operations.load({ operation: 'getParticipant', args });
        case 'LocalProcessParticipant':
            return !args.onBehalfOf
                ? context.loaders.participants.load(id)
                : context.loaders.operations.load({ operation: 'getParticipant', args });
        case 'ProcessParticipantProfile':
            return context.loaders.operations.load({ operation: 'getProcessParticipantProfile', args });
        case 'Delegation':
            return context.loaders.operations.load({ operation: 'getDelegation', args });
        case 'ProcessData':
            return context.loaders.operations.load({ operation: 'getProcessData', args });
        case 'Comment':
            return context.loaders.operations.load({ operation: 'getComment', args });
        case 'RequestData':
            return context.loaders.operations.load({ operation: 'getRequestData', args });
        case 'ActionData':
            return context.loaders.operations.load({ operation: 'getActionData', args });
        case 'DelegableProcessParticipant':
            return context.loaders.operations.load({ operation: 'getDelegableProcessParticipant', args });
        case 'Favorite':
            return context.loaders.operations.load({ operation: 'getFavorite', args });
        case 'Directory':
            return context.loaders.operations.load({ operation: 'getDirectory', args });
        case 'Group':
            return context.loaders.operations.load({ operation: 'getGroup', args });
        case 'Application':
            return context.loaders.operations.load({ operation: 'getApplication', args });
        case 'ApplicationParameter':
            return context.loaders.operations.load({ operation: 'getApplicationParameter', args });
        case 'ActionParameter':
            return context.loaders.operations.load({ operation: 'getActionParameter', args });
        case 'GlobalList':
            return context.loaders.operations.load({ operation: 'getGlobalList', args });
        default:
            return Promise.reject(new Error(`Could not resolve to a node with the global id of '${id}'.`));
    }
}
function invokeLoader(loaderName, key, context) {
    context.incrementResolverCount();
    return context.loaders[loaderName].load(key);
}
exports.default = {
    Query: {
        node: (root, args, context) => getKeyForGlobalId(args.id, root, args, context),
        nodes: (root, args, context) => args.ids.map((id) => getKeyForGlobalId(id, root, {
            id, onBehalfOf: args.onBehalfOf || undefined
        }, context)),
        server: (root, args, context) => invokeLoader('operations', {
            operation: 'getServer', args
        }, context),
        viewer(root, args, context) {
            return __awaiter(this, void 0, void 0, function* () {
                const user = yield invokeLoader('operations', {
                    operation: 'getViewer', args
                }, context);
                context.loaders.users.prime(user.id, user);
                return user;
            });
        },
        user: (root, args, context) => invokeLoader('usersByUserName', args.userName.toLowerCase(), context),
        users: (root, args, context) => invokeLoader('operations', {
            operation: 'getUsers', args
        }, context),
        group: (root, args, context) => invokeLoader('operations', {
            operation: 'getGroup', args
        }, context),
        groups: (root, args, context) => invokeLoader('operations', {
            operation: 'getGroups', args
        }, context),
        directory: (root, args, context) => invokeLoader('operations', {
            operation: 'getDirectory', args
        }, context),
        directories: (root, args, context) => invokeLoader('operations', {
            operation: 'getDirectories', args
        }, context),
        process: (root, args, context) => invokeLoader('operations', {
            operation: 'getProcess', args
        }, context),
        processFolder: (root, args, context) => invokeLoader('operations', {
            operation: 'getProcessFolder', args
        }, context),
        processFolders: (root, args, context) => invokeLoader('operations', {
            operation: 'getProcessFolders', args
        }, context),
        processes: (root, args, context) => invokeLoader('operations', {
            operation: 'getProcesses', args
        }, context),
        request: (root, args, context) => invokeLoader('operations', {
            operation: 'getRequest', args
        }, context),
        requests: (root, args, context) => invokeLoader('operations', {
            operation: 'getRequests', args
        }, context),
        action: (root, args, context) => invokeLoader('operations', {
            operation: 'getAction', args
        }, context),
        actions: (root, args, context) => invokeLoader('operations', {
            operation: 'getActions', args
        }, context),
        globalParticipant: (root, args, context) => invokeLoader('operations', {
            operation: 'getGlobalParticipant', args
        }, context),
        localProcessParticipant: (root, args, context) => invokeLoader('operations', {
            operation: 'getLocalProcessParticipant', args
        }, context),
        participants: (root, args, context) => invokeLoader('operations', {
            operation: 'getParticipants', args
        }, context),
        delegations: (root, args, context) => invokeLoader('operations', {
            operation: 'getDelegations', args
        }, context),
        application: (root, args, context) => invokeLoader('operations', {
            operation: 'getApplication', args
        }, context),
        applications: (root, args, context) => invokeLoader('operations', {
            operation: 'getApplications', args
        }, context),
        category: (root, args, context) => invokeLoader('categoryByName', args.name, context),
        categories: (root, args, context) => invokeLoader('operations', {
            operation: 'getCategories', args
        }, context),
        globalList: (root, args, context) => invokeLoader('operations', {
            operation: 'getGlobalList', args
        }, context),
        globalLists: (root, args, context) => invokeLoader('operations', {
            operation: 'getGlobalLists', args
        }, context)
    }
};
