"use strict";
/**
 * request.ts
 * GraphQL resolvers
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = {
    Request: {
        requester(request, args, context) {
            context.incrementResolverCount();
            return context.loaders.users.load(request.requesterId);
        },
        delegatedRequester(request, args, context) {
            if (!request.delegatedRequesterId) {
                return null;
            }
            context.incrementResolverCount();
            return context.loaders.users.load(request.delegatedRequesterId);
        },
        abortedBy(request, args, context) {
            if (!request.abortedById) {
                return null;
            }
            context.incrementResolverCount();
            return context.loaders.users.load(request.abortedById);
        },
        parentAction(request, args, context) {
            if (!request.parentActionId) {
                return null;
            }
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getAction',
                args: {
                    id: request.parentActionId,
                    userId: request.userId || undefined,
                    onBehalfOf: request.onBehalfOf || undefined
                }
            });
        },
        process(request, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getProcess',
                args: Object.assign(args, {
                    id: request.processId,
                    userId: request.userId || undefined,
                    onBehalfOf: request.onBehalfOf || undefined
                })
            });
        },
        actions(request, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getActions',
                args: Object.assign(args, {
                    filter: Object.assign(args.filter || {}, { requestId: request.id }),
                    userId: request.userId || undefined,
                    onBehalfOf: request.onBehalfOf || undefined
                })
            });
        },
        comments(request, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getCommentsByRequest',
                args: Object.assign(args, {
                    requestId: request.id,
                    userId: request.userId || undefined,
                    onBehalfOf: request.onBehalfOf || undefined
                })
            });
        },
        dataset(request, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getRequestDataset',
                args: Object.assign(args, {
                    requestId: request.id,
                    userId: request.userId || undefined,
                    onBehalfOf: request.onBehalfOf || undefined
                })
            });
        },
        canCancel(request, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'canCancelRequest',
                args: Object.assign(args, {
                    id: request.id,
                    userId: request.userId || undefined,
                    onBehalfOf: request.onBehalfOf || undefined
                })
            });
        },
        canDelete(request, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'canDeleteRequest',
                args: Object.assign(args, {
                    id: request.id,
                    userId: request.userId || undefined,
                    onBehalfOf: request.onBehalfOf || undefined
                })
            });
        },
        canReadComments(request, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'canReadRequestComments',
                args: Object.assign(args, {
                    id: request.id,
                    userId: request.userId || undefined,
                    onBehalfOf: request.onBehalfOf || undefined
                })
            });
        },
        canWriteComments(request, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'canWriteRequestComments',
                args: Object.extend(args, {
                    id: request.id,
                    userId: request.userId || undefined,
                    onBehalfOf: request.onBehalfOf || undefined
                })
            });
        }
    }
};
