"use strict";
/**
 * user.ts
 * GraphQL resolvers
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = {
    User: {
        manager(user, args, context) {
            if (!user.managerId) {
                return null;
            }
            context.incrementResolverCount();
            return context.loaders.users.load(user.managerId);
        },
        directory(user, args, context) {
            if (!user.directoryId) {
                return null;
            }
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getDirectory',
                args: Object.extend({}, {
                    id: user.directoryId,
                    userAsMember: true
                })
            });
        },
        groups(user, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getGroups',
                args: Object.extend(args, {
                    userId: user.id,
                    userAsMember: true
                })
            });
        },
        processes(user, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getProcesses',
                args: Object.extend(args, {
                    userId: user.id,
                    userAsMember: true
                })
            });
        },
        launchableProcesses(user, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getLaunchableProcesses',
                args: Object.extend(args, {
                    userId: user.id
                })
            });
        },
        requests(user, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getRequests',
                args: Object.extend(args, {
                    userId: user.id,
                    userAsMember: true
                })
            });
        },
        actions(user, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getActions',
                args: Object.extend(args, {
                    userId: user.id,
                    userAsMember: true
                })
            });
        },
        comments(user, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getComments',
                args: Object.extend(args, {
                    userId: user.id
                })
            });
        },
        participants(user, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getParticipants',
                args: Object.extend(args, {
                    userId: user.id,
                    userAsMember: true
                })
            });
        },
        favorites(user, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getFavorites',
                args: Object.extend(args, {
                    userId: user.id
                })
            });
        },
        views(user, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getViews',
                args: Object.extend(args, {
                    userId: user.id
                })
            });
        },
        delegations(user, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getDelegations',
                args: Object.extend(args, {
                    userId: user.id
                })
            });
        },
        delegators(user, args, context) {
            return __awaiter(this, void 0, void 0, function* () {
                context.incrementResolverCount();
                const result = yield context.loaders.operations.load({
                    operation: 'getDelegators',
                    args: Object.extend(args, { userId: user.id })
                });
                result.items = result.items.map((id) => {
                    context.incrementResolverCount();
                    return context.loaders.users.load(id);
                });
                return result;
            });
        },
        delegableProcessParticipants(user, args, context) {
            context.incrementResolverCount();
            return context.loaders.operations.load({
                operation: 'getDelegableProcessParticipants',
                args: Object.extend(args, {
                    userId: user.id
                })
            });
        }
    }
};
