"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * schema.ts
 * GraphQL Schema
 */
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const lodash_merge_1 = __importDefault(require("lodash.merge"));
const graphql_tools_1 = require("graphql-tools");
/**
 * Creates a GraphQL Schema.
 * @param config A configuration.
 * @return The schema.
 */
function createSchema(config) {
    // Load type definitions
    const typeDefs = [];
    fs
        .readdirSync(path.join(__dirname, 'typedefs'))
        .filter(fileName => path.extname(fileName) === '.js')
        .forEach(file => typeDefs.push(require(`./typedefs/${file}`).default));
    // Load resolvers
    const resolvers = {};
    fs
        .readdirSync(path.join(__dirname, 'resolvers'))
        .filter(fileName => path.extname(fileName) === '.js')
        .forEach(file => lodash_merge_1.default(resolvers, require(`./resolvers/${file}`).default));
    // Creates the schema
    const schema = graphql_tools_1.makeExecutableSchema({ typeDefs, resolvers });
    // Load mocks if needed
    if (config.mocksEnabled) {
        const mocks = {};
        fs
            .readdirSync(path.join(__dirname, 'mocks'))
            .forEach(file => lodash_merge_1.default(mocks, require(`./mocks/${file}`)));
        // Add mocks if needed, modifies schema in place
        graphql_tools_1.addMockFunctionsToSchema({ schema, preserveResolvers: true, mocks });
    }
    return schema;
}
exports.createSchema = createSchema;
