"use strict";
/**
 * actiondata.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# An action data.
type ActionData implements Node & WorkflowData {

  # Identifies the action associated to the action data.
  action: Action!

  # Action data date and time value.
  dateTimeValue: DateTime

  # Action data description.
  description: String!

  # Action data file value.
  fileValue: File

  # Indicates if the action data has a value.
  hasValue: Boolean!

  # Action data identifier.
  id: ID!

  # Action data name.
  name: String!

  # Action data numeric value.
  numericValue: Float

  # Action data text value.
  textValue: String

  # Action data type.
  type: WorkflowDataType!
}

# A paginated list of action data.
type ActionDataListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of action data.
  items: [ActionData]
}

# A filter on action data.
input ActionDataFilter {

  # Filter action data by name.
  names: [String]

  # Filter action data by type.
  type: WorkflowDataType
}

# An action data list order.
input ActionDataListOrder {

  # Field by which to order action data.
  field: ActionDataListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# List possible fields to order an action data list.
enum ActionDataListOrderField {

  # Order action data by name.
  NAME

  # Order action data by type.
  TYPE

  # Order action data by display order.
  DISP_ORDER
}

`;
