"use strict";
/**
 * activity.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# An activity.
type Activity implements Node {

  # Identifies the application associated to the activity.
  application: Application

  # Activity description.
  description: String!

  # Indicates if the activity has Quick Approval parameters.
  hasQuickApproval: Boolean

  # Activity help information.
  help: Help

  # Activity identifier.
  id: ID!

  # Indicates if the activity is a form-based application.
  isForm: Boolean

  # Indicates if the action is displayed in the request's actions history.
  isVisibleInHistory: Boolean

  # Activity name.
  name: String!

  # Identifies the participant associated to the activity.
  participant: Participant

  # Identifies the process associated to the activity.
  process: Process!

  # Identifies the sub-process associated to the activity.
  subProcess: Process

  # Quick approval parameters.
  quickApprovalParameters: ActivityParameterListPage

  # Activity type.
  type: ActivityType!

  # Sub-process type.
  subProcessType: SubProcessType
}

# A paginated list of activities.
type ActivityListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of activities.
  items: [Activity]
}

# A filter on activities.
input ActivityFilter {

  # Filter activities by visibility in history
  isVisibleInHistory: Boolean

  # Filter activities by type.
  type: ActivityType
}

# An activity list order.
input ActivityListOrder {

  # Field by which to order activities.
  field: ActivityListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# List of possible fields to order an activity list.
enum ActivityListOrderField {

  # Order activities by name.
  NAME

  # Order activities by display order.
  DISP_ORDER
}

# Represents the possible activity types.
enum ActivityType {

  # Application.
  APPLICATION

  # Manual action.
  MANUAL

  # Synchronization.
  ROUTE

  # Sub-process.
  SUBFLOW
}

# Represents the possible sub-process types.
enum SubProcessType {

  # Embedded.
  EMBEDDED

  # Independent.
  INDEPENDENT
}
`;
