"use strict";
/**
 * category.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# A category.
type Category implements Node {

  # Category description.
  description: String!

  # Category identifier.
  id: ID!

  # List of launchable processes associated to this category.
  launchableProcesses (page: Page, orderBy: ProcessListOrder): ProcessListPage

  # Category name.
  name: String!

  # List of processes associated to this category.
  processes (page: Page, orderBy: ProcessListOrder, filter: CategoryProcessFilter): ProcessListPage
}

# A paginated list of categories.
type CategoryListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of categories.
  items: [Category]
}

# A filter on categories.
input CategoryFilter {

  # Filter categories by description.
  descriptionContains: String

  # Filter categories by name.
  nameContains: String

  # Filter categories by process ID.
  processId: ID
}

# A category list order.
input CategoryListOrder {

  # Field by which to order categories.
  field: CategoryListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# List possible fields to order a category list.
enum CategoryListOrderField {

  # Order categories by name.
  NAME

  # Order categories by description.
  DESCRIPTION
}

# A filter on category processes.
input CategoryProcessFilter {

  # Filter by state.
  state: ProcessState
}

# Create category input.
input CreateCategoryInput {

  # Client mutation identifier.
  clientMutationId: String

  # Category description.
  description: String!

  # Category name.
  name: String!
 }

# Create category result.
type CreateCategoryResult {

  # Client mutation identifier.
  clientMutationId: String

  # Category that has been created.
  category: Category!
}

# Update category input.
input UpdateCategoryInput {

  # Client mutation identifier.
  clientMutationId: String

  # Category identifier.
  id: ID!

  # Category name.
  name: String

  # Category description.
  description: String
}

# Update category result.
type UpdateCategoryResult {

  # Client mutation identifier.
  clientMutationId: String

  # Category that has been updated.
  category: Category!
}

# Delete category input.
input DeleteCategoryInput {

  # Client mutation identifier.
  clientMutationId: String

  # Category identifier.
  id: ID!
}

# Delete category result.
type DeleteCategoryResult {

  # Client mutation identifier.
  clientMutationId: String
}
`;
