"use strict";
/**
 * comment.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# A comment.
type Comment implements Node {

  # The user who posted the comment.
  author: User!

  # Comment identifier.
  id: ID!

  # The message of the comment.
  message: String!

  # Identifies the date and time when the comment was posted.
  postedAt: DateTime!

  # The object on which the comment was added.
  subject: Node!
}

# A paginated list of comments.
type CommentListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of comments.
  items: [Comment]
}

# A comment list order.
input CommentListOrder {

  # Field by which to order comments.
  field: CommentListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# A list of fields by which to order a list of comments.
enum CommentListOrderField {

  # Order comments by when the comments were posted.
  POSTED_AT

  # Order comments by the name of the author.
  AUTHOR_NAME
}

# Add a comment input.
input AddCommentInput {

  # Client mutation identifier.
  clientMutationId: String

  # New comment message.
  message: String!

  # Identifier of the object on which the comment will be added.
  subjectId: ID!
}

# Add a comment result.
type AddCommentResult {

  # Comment that has been added.
  comment: Comment!

  # Client mutation identifier.
  clientMutationId: String
}

# Update a comment input.
input UpdateCommentInput {

  # Client mutation identifier.
  clientMutationId: String

  # Comment identifier.
  id: ID!

  # Updated comment message.
  message: String!
}

# Update a comment result.
type UpdateCommentResult {

  # Comment that has been updated.
  comment: Comment!

  # Client mutation identifier.
  clientMutationId: String
}

# A remove comment input.
input RemoveCommentInput {

  # Client mutation identifier.
  clientMutationId: String

  # Comment identifier.
  id: ID!
}

# A remove comment result.
type RemoveCommentResult {

  # Client mutation identifier.
  clientMutationId: String
}

`;
