"use strict";
/**
 * delegation.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# A delegation.
type Delegation implements Node {

  # User who is designated by the delegator.
  delegatee: User

  # User who delegates.
  delegator: User!

  # Identifies the date and time when the delegation ends.
  end: DateTime

  # Delegation identifier.
  id: ID!

  # Participant associated to the delegation.
  participant: Participant

  # Process associated to the delegation.
  process: Process

  # Identifies the date and time when the delegation starts.
  start: DateTime
}

# A DelegableProcessParticipant
type DelegableProcessParticipant implements Node {

  # Delegable process and participant identifier.
  id: ID!

  # Participant.
  participant: Participant!

  # Process.
  process: Process!
}

# A paginated list of delegations.
type DelegationListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of delegations.
  items: [Delegation]
}

# A paginated list of delegable process participants.
type DelegableProcessParticipantListPage {
   # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of delegable process participants.
  items: [DelegableProcessParticipant]
}

# A delegation list order.
input DelegationListOrder {

  # Field by which to order delegations.
  field: DelegationListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# A delegable process participant list order.
input DelegableProcessParticipantOrder {

  # Ordering direction.
  direction: ListOrderDirection

  # Field by which to order delegable process participants.
  field: DelegableProcessParticipantField
}

# A list of fields by which to order a delegable process participant list.
enum DelegableProcessParticipantField {

  # Order by process name.
  PROCESS_NAME

  # Order by participant name.
  PARTICIPANT_NAME
}

# A list of fields by which to order a delegation list.
enum DelegationListOrderField {

  # Order by delegation start date.
  START_DATE

  # Order by delegation end date.
  END_DATE

  # Order by delegatee name.
  DELEGATEE_NAME

  # Order by process name.
  PROCESS_NAME

  # Order by participant name.
  PARTICIPANT_NAME
}

# A filter on delegations.
input DelegationFilter {

  # Indicates if the delegations are active.
  isActive: Boolean
}

# A filter on delegations.
input DelegableProcessParticipantFilter {

  # Filter by category identifier.
  categoryId: ID

  # Filter by participant identifier.
  participantId: ID

  # Filter by process identifier.
  processId: ID
}

# A create delegation input.
input CreateDelegationInput {

  # Client mutation identifier.
  clientMutationId: String

  # Identifies the user who is the delegatee.
  delegateeId: ID!

  # Identifies the user who is the delegator.
  delegatorId: ID

  # Indicates the date and time when the delegation ends.
  end: DateTime

  # Indicates if the delegatee has to be notified.
  notifyDelegatee: Boolean

  # Identifies the participant associated to the delegation.
  participantId: ID

  # Identifies the process associated to the delegation.
  processId: ID

  # Indicates the date and time when the delegation starts.
  start: DateTime
}

# A create delegation result.
type CreateDelegationResult {

  # Client mutation identifier.
  clientMutationId: String

  # The delegation that has been created.
  delegation: Delegation!
}

# A update delegation input.
input UpdateDelegationInput {

  # Client mutation identifier.
  clientMutationId: String

  # Identifies the user who is the delegatee.
  delegateeId: ID

  # Identifies the user who is the delegator.
  delegatorId: ID

  # Indicates the date and time when the delegation ends.
  end: DateTime

  # Delegation identifier.
  id: ID!

  # Indicates if the delegatee has to be notified.
  notifyDelegatee: Boolean

  # Identifies the participant associated to the delegation.
  participantId: ID

  # Identifies the process associated to the delegation.
  processId: ID

  # Indicates the date and time when the delegation starts.
  start: DateTime
}

# A update delegation result.
type UpdateDelegationResult {

  # Client mutation identifier.
  clientMutationId: String

  # The delegation that has been updated.
  delegation: Delegation!
}

# A delete delegation input.
input DeleteDelegationInput {

  # Client mutation identifier.
  clientMutationId: String

  # Delegation identifier.
  id: ID!
}

# A delete delegation result.
type DeleteDelegationResult {

  # Client mutation identifier.
  clientMutationId: String
}

`;
