"use strict";
/**
 * favorite.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# A favorite.
type Favorite implements Node {

  # Favorite description.
  description: String!

  # Favorite identifier.
  id: ID!

  # Favorite item.
  item: Node!

  # Identifies the user who added the favorite.
  owner: User!

  # Favorite type.
  type: FavoriteType!
}

# Represents the possible favorite types.
enum FavoriteType {

  # Process type favorite.
  PROCESS

  # View type favorite.
  VIEW
}

# A paginated list of favorites.
type FavoriteListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of favorites.
  items: [Favorite]
}

# A filter on favorites.
input FavoriteFilter {

  # Filter favorites by type
  type: FavoriteType
}

# A favorite list order.
input FavoriteListOrder {

  # Field by which to order favorites.
  field: FavoriteListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# A list of fields by which to order a favorite list.
enum FavoriteListOrderField {

  # Order by type.
  TYPE
}

# A create favorite input.
input CreateFavoriteInput {

  # Client mutation identifier.
  clientMutationId: String

  # Favorite description.
  description: String

  # Favorite item.
  itemId: ID!
}

# A create favorite result.
type CreateFavoriteResult {

  # Client mutation identifier.
  clientMutationId: String

  # Favorite that has been created.
  favorite: Favorite!
}

# An update favorite input.
input UpdateFavoriteInput {

  # Client mutation identifier.
  clientMutationId: String

  # Favorite description.
  description: String

  # Favorite identifier.
  id: ID!
}

# An update favorite result.
type UpdateFavoriteResult {

  # Client mutation identifier.
  clientMutationId: String

  # The favorite that has been updated.
  favorite: Favorite!
}

# A delete favorite input.
input DeleteFavoriteInput {

  # Client mutation identifier.
  clientMutationId: String

  # Favorite identifier.
  id: ID!
}

# A delete favorite result.
type DeleteFavoriteResult {

  # Client mutation identifier.
  clientMutationId: String
}

`;
