"use strict";
/**
 * globallist.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# A global list.
type GlobalList implements Node {

  # Global list connection name.
  connectionName: String

  # Global list connection string.
  connectionString: String

  # Global list identifier.
  id: ID!

  # Global list name.
  name: String!

  # Global list manager.
  manager: GlobalParticipant

  # Global list provider name.
  providerName: GlobalListDatabaseProvider

  # Global list select command.
  selectCommand: String

  # Date and time when the global list was updated.
  updatedAt: DateTime!

  # User that updated the global list.
  updatedBy: User

  # Global list definition in XML format.
  xmlDefinition: File!
}

# Create global list input.
 input CreateGlobalListInput {

  # Client mutation identifier.
  clientMutationId: String

  # Global list connection name.
  connectionName: String

  # Global list connection string.
  connectionString: String

  # Global list name.
  name: String

  # Global list manager identifier (global participant).
  managerId: ID

  # Duplicates a global list given its identifier.
  fromGlobalListId: ID

  # Global list provider name.
  providerName: GlobalListDatabaseProvider

  # Global list select command.
  selectCommand: String
}

# Create global list result.
type CreateGlobalListResult {

  # Client mutation identifier.
  clientMutationId: String

  # Global list that has been created.
  globalList: GlobalList!
}

# Create global list from an XML definition input.
 input CreateGlobalListFromXmlDefinitionInput {

  # Client mutation identifier.
  clientMutationId: String

  # Global list definition in XML format.
  xmlDefinition: FileInput
 }

 # Create global list from an XML definition result.
type CreateGlobalListFromXmlDefinitionResult {

  # Client mutation identifier.
  clientMutationId: String

  # Global list that has been created.
  globalList: GlobalList!
}

# Update global list input.
 input UpdateGlobalListInput {

  # Client mutation identifier.
  clientMutationId: String

  # Global list connection name.
  connectionName: String

  # Global list connection string.
  connectionString: String

  # Global list identifier
  id: ID!

  # Global list name.
  name: String

  # Global list manager identifier (global participant).
  managerId: ID

  # Global list provider name.
  providerName: GlobalListDatabaseProvider

  # Global list select command.
  selectCommand: String
}

# Update global list result.
type UpdateGlobalListResult {

  # Client mutation identifier.
  clientMutationId: String

  # Global list that has been updated.
  globalList: GlobalList!
}

# Update global list from an XML definition input.
 input UpdateGlobalListFromXmlDefinitionInput {

 # Client mutation identifier.
  clientMutationId: String

 # Global list identifier.
  id: ID!

  # Global list definition in XML format.
  xmlDefinition: FileInput
 }

 # Update global list from an XML definition result.
type UpdateGlobalListFromXmlDefinitionResult {

  # Client mutation identifier.
  clientMutationId: String

  # Global list that has been updated.
  globalList: GlobalList!
}

# Delete global list input.
input DeleteGlobalListInput {

  # Client mutation identifier.
  clientMutationId: String

  # Global list identifier.
  id: ID!
}

# Delete global list result.
type DeleteGlobalListResult {

  # Client mutation identifier.
  clientMutationId: String
}

# A filter on global lists.
input GlobalListFilter{

  # Filter global lists by name.
  nameContains: String
}

# A paginated list of global lists.
type GlobalListListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of global lists.
  items: [GlobalList]
}

# A global list order.
input GlobalListListOrder {

  # Field by which to order global lists.
  field: GlobalListListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# List of possible global list database providers
enum GlobalListDatabaseProvider {

  # .NET Framework Data Provider for SQL Server.
  SYSTEM_DATA_SQLCLIENT

  # .NET Framework Data Provider for OLE DB.
  SYSTEM_DATA_OLEDB

  # .NET Framework Data Provider for ODBC.
  SYSTEM_DATA_ODBC

  # .NET Framework Data Provider for Oracle.
  SYSTEM_DATA_ORACLECLIENT

  # Oracle Data Provider for .NET.
  ORACLE_DATAACCESS_CLIENT
}

# List of possible fields to order a global lists list.
enum GlobalListListOrderField {

  # Order global lists by name.
  NAME

  # Order global lists by when they were updated.
  UPDATED_AT
}
`;
