"use strict";
/**
 * mutation.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# the schema allows the following mutation:
type Mutation {

  # Creates a new a request.
  createRequest (input: CreateRequestInput): CreateRequestResult

  # Cancels a request.
  cancelRequest (input: CancelRequestInput): CancelRequestResult

  # Deletes a request.
  deleteRequest (input: DeleteRequestInput): DeleteRequestResult

  # Updates request dataset.
  updateRequestDataset (input: UpdateRequestDatasetInput): UpdateRequestDatasetResult

  # Completes an action.
  completeAction (input: CompleteActionInput): CompleteActionResult

  # Completes a form action.
  completeFormAction (input: CompleteActionInput): CompleteActionResult

  # Assigns an action.
  assignAction (input: AssignActionInput): AssignActionResult

  # Cancels an action assignment
  cancelActionAssignment (input: CancelActionAssignmentInput): CancelActionAssignmentResult

  # Cancels an action.
  cancelAction (input: CancelActionInput): CancelActionResult

  # Cancels a request's actions by name.
  cancelRequestActionsByName (input: CancelRequestActionsByNameInput): CancelRequestActionsByNameResult

  # Starts an interactive action.
  startInteractiveAction (input: StartInteractiveActionInput): StartInteractiveActionResult

  # Creates a delegation.
  createDelegation (input: CreateDelegationInput): CreateDelegationResult

  # Updates a delegation.
  updateDelegation (input: UpdateDelegationInput): UpdateDelegationResult

  # Deletes a delegation.
  deleteDelegation (input: DeleteDelegationInput): DeleteDelegationResult

  # Adds a new comment.
  addComment (input: AddCommentInput): AddCommentResult

  # Updates a comment.
  updateComment (input: UpdateCommentInput): UpdateCommentResult

  # Removes a comment.
  removeComment (input: RemoveCommentInput): RemoveCommentResult

  # Creates a favorite.
  createFavorite (input: CreateFavoriteInput): CreateFavoriteResult

  # Updates a favorite.
  updateFavorite (input: UpdateFavoriteInput): UpdateFavoriteResult

  # Deletes a favorite.
  deleteFavorite (input: DeleteFavoriteInput): DeleteFavoriteResult

  # Creates a new user.
  createUser (input: CreateUserInput): CreateUserResult

  # Updates a user.
  updateUser (input: UpdateUserInput): UpdateUserResult

  # Deletes a user.
  deleteUser (input: DeleteUserInput): DeleteUserResult

  # Updates the viewer preferences.
  updateViewerPreferences (input: UpdateViewerPreferencesInput): UpdateViewerPreferencesResult

  # Creates a new group.
  createGroup (input: CreateGroupInput): CreateGroupResult

  # Updates a group.
  updateGroup (input: UpdateGroupInput): UpdateGroupResult

  # Deletes a group.
  deleteGroup (input: DeleteGroupInput): DeleteGroupResult

  # Adds users to a group.
  addUsersToGroup (input: AddUsersToGroupInput): AddUsersToGroupResult

  # Removes users from a group.
  removeUsersFromGroup (input: RemoveUsersFromGroupInput): RemoveUsersFromGroupResult

  # Adds groups to a user.
  addGroupsToUser (input: AddGroupsToUserInput): AddGroupsToUserResult

  # Removes groups from a user.
  removeGroupsFromUser (input: RemoveGroupsFromUserInput): RemoveGroupsFromUserResult

  # Creates an application.
  createApplication (input: CreateApplicationInput): CreateApplicationResult

  # Updates an application.
  updateApplication (input: UpdateApplicationInput): UpdateApplicationResult

  # Deletes an application.
  deleteApplication (input: DeleteApplicationInput): DeleteApplicationResult

  # Adds an application parameter.
  addApplicationParameter (input: AddApplicationParameterInput): AddApplicationParameterResult

  # Remove an application parameter.
  removeApplicationParameter (input: RemoveApplicationParameterInput): RemoveApplicationParameterResult

  # Creates a category.
  createCategory (input: CreateCategoryInput): CreateCategoryResult

  # Updates a category.
  updateCategory (input: UpdateCategoryInput): UpdateCategoryResult

  # Deletes a category.
  deleteCategory (input: DeleteCategoryInput): DeleteCategoryResult

  # Creates a process folder.
  createProcessFolder (input: CreateProcessFolderInput): CreateProcessFolderResult

  # Updates a process folder.
  updateProcessFolder (input: UpdateProcessFolderInput): UpdateProcessFolderResult

  # Deletes a process folder.
  deleteProcessFolder (input: DeleteProcessFolderInput): DeleteProcessFolderResult

  # Creates a process.
  createProcess (input: CreateProcessInput): CreateProcessResult

  # Creates a process from an XPDL definition.
  createProcessFromXpdl (input: CreateProcessFromXpdlInput): CreateProcessFromXpdlResult

  # Updates a process.
  updateProcess (input: UpdateProcessInput): UpdateProcessResult

  # Updates a process from an XPDL definition.
  updateProcessFromXpdl (input: UpdateProcessFromXpdlInput): UpdateProcessFromXpdlResult

  # Deletes a process.
  deleteProcess (input: DeleteProcessInput): DeleteProcessResult

  # Creates a global participant.
  createGlobalParticipant (input: CreateGlobalParticipantInput): CreateGlobalParticipantResult

  # Updates a global participant.
  updateGlobalParticipant (input: UpdateGlobalParticipantInput): UpdateGlobalParticipantResult

  # Deletes a global participant.
  deleteGlobalParticipant (input: DeleteGlobalParticipantInput): DeleteGlobalParticipantResult

  # Adds a process participant profile.
  addProcessParticipantProfile (input: AddProcessParticipantProfileInput): AddProcessParticipantProfileResult

  # Updates a process participant profile.
  updateProcessParticipantProfile (input: UpdateProcessParticipantProfileInput): UpdateProcessParticipantProfileResult

  # Removes a process participant profile.
  removeProcessParticipantProfile (input: RemoveProcessParticipantProfileInput): RemoveProcessParticipantProfileResult

  # Creates a local process participant.
  createLocalProcessParticipant (input: CreateLocalProcessParticipantInput): CreateLocalProcessParticipantResult

  # Updates a local process participant.
  updateLocalProcessParticipant (input: UpdateLocalProcessParticipantInput): UpdateLocalProcessParticipantResult

  # Deletes a local process participant.
  deleteLocalProcessParticipant (input: DeleteLocalProcessParticipantInput): DeleteLocalProcessParticipantResult

  # Creates a global list.
  createGlobalList (input: CreateGlobalListInput): CreateGlobalListResult

  # Creates a global list from an XML definition.
  createGlobalListFromXmlDefinition (input: CreateGlobalListFromXmlDefinitionInput): CreateGlobalListFromXmlDefinitionResult

  # Updates a global list.
  updateGlobalList (input: UpdateGlobalListInput): UpdateGlobalListResult

  # Updates a global list from an XML definition.
  updateGlobalListFromXmlDefinition (input: UpdateGlobalListFromXmlDefinitionInput): UpdateGlobalListFromXmlDefinitionResult

  # Deletes a global list.
  deleteGlobalList (input: DeleteGlobalListInput): DeleteGlobalListResult

  # Registers a push notification token.
  registerViewerPushNotificationToken (input: RegisterViewerPushNotificationTokenInput): RegisterViewerPushNotificationTokenResult

  # Unregisters a push notification token.
  unregisterViewerPushNotificationToken (input: UnregisterViewerPushNotificationTokenInput): UnregisterViewerPushNotificationTokenResult

}

`;
