"use strict";
/**
 * participant.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# An interface participant.
interface Participant {

  # List of the coordinators associated to the participant.
  coordinators(page: Page, orderBy: UserListOrder): UserListPage

  # Participant description.
  description: String!

  # List of the directories associated to the participant.
  directories(page: Page, orderBy: DirectoryListOrder): DirectoryListPage

  # List of the groups associated to the participant.
  groups(page: Page, orderBy: GroupListOrder): GroupListPage

  # Participant identifier.
  id: ID!

  # Participant name.
  name: String

  # Participant type.
  type: ParticipantType

  # List of the users associated to the participant.
  users(page: Page, orderBy: UserListOrder): UserListPage
}

# A global participant.
type GlobalParticipant implements Node & Participant {

  # List of the coordinators associated to the global participant.
  coordinators(page: Page, orderBy: UserListOrder): UserListPage

  # Global participant description.
  description: String!

  # List of the directories associated to the global participant.
  directories(page: Page, orderBy: DirectoryListOrder): DirectoryListPage

  # List of the groups associated to the global participant.
  groups(page: Page, orderBy: GroupListOrder): GroupListPage

  # Global participant identifier.
  id: ID!

  # Global participant name.
  name: String

  # Global participant type.
  type: ParticipantType

  # List of the users associated to the global participant.
  users(page: Page, orderBy: UserListOrder): UserListPage
}

# A local process participant.
type LocalProcessParticipant implements Node & Participant {

  # List of the coordinators associated to the local process participant.
  coordinators(page: Page, orderBy: UserListOrder): UserListPage

  # Local process participant description.
  description: String!

  # List of the directories associated to the local process participant.
  directories(page: Page, orderBy: DirectoryListOrder): DirectoryListPage

  # List of the groups associated to the local process participant.
  groups(page: Page, orderBy: GroupListOrder): GroupListPage

  # Local process participant identifier.
  id: ID!

  # Local process participant name.
  name: String

  # Local process participant process.
  process: Process!

  # Local process participant type.
  type: ParticipantType

  # List of the users associated to the local process participant.
  users(page: Page, orderBy: UserListOrder): UserListPage
}

# Create global participant input.
input CreateGlobalParticipantInput {

  # Client mutation identifier.
  clientMutationId: String

  # List of the coordinators associated to the global participant.
  coordinatorIds: [ID]

  # Global participant description
  description: String!

  # List of directories associated to the global participant.
  directoryIds: [ID]

  # List of groups associated to the global participant.
  groupIds: [ID]

  # Global participant name
  name: String!

  # Global participant type
  type: ParticipantType!

  # List of users associated to the global participant.
  userIds: [ID]
}

# Create global participant result.
type CreateGlobalParticipantResult {

  # Client mutation identifier.
  clientMutationId: String

  # Global participant that has been created.
  globalParticipant: GlobalParticipant!
}

# Update global participant input.
input UpdateGlobalParticipantInput {

  # Client mutation identifier.
  clientMutationId: String

  # List of the coordinators associated to the global participant.
  coordinatorIds: [ID]

  # Global participant description.
  description: String

  # List of directories associated to the global participant.
  directoryIds: [ID]

  # List of groups associated to the global participant.
  groupIds: [ID]

  # Global participant identifier.
  id: ID!

  # Global participant name.
  name: String

  # Global participant type.
  type: ParticipantType

  # List of users associated to the global participant.
  userIds: [ID]
}

# Update global participant result.
type UpdateGlobalParticipantResult {

  # Client mutation identifier.
  clientMutationId: String

  # Global participant that has been updated.
  globalParticipant: GlobalParticipant!
}

# Delete global participant input.
input DeleteGlobalParticipantInput {

  # Client mutation identifier.
  clientMutationId: String

  # Global participant identifier.
  id: ID!
}

# Delete global participant result.
type DeleteGlobalParticipantResult {

  # Client mutation identifier.
  clientMutationId: String
}

# Create local process participant input.
input CreateLocalProcessParticipantInput {

  # Client mutation identifier.
  clientMutationId: String

  # List of coordinators associated to the local process participant.
  coordinatorIds: [ID]

  # Local process participant description.
  description: String!

  # List of directories associated to the local process participant.
  directoryIds: [ID]

  # List of groups associated to the local process participant.
  groupIds: [ID]

  # Local process participant name.
  name: String!

  # Process identifier.
  processId: ID!

  # Local process participant type.
  type: ParticipantType!

  # List of users associated to the local process participant.
  userIds: [ID]
}

# Create local process participant result.
type CreateLocalProcessParticipantResult {

  # Client mutation identifier.
  clientMutationId: String

  # Local process participant that has been created.
  localProcessParticipant: LocalProcessParticipant!
}

# Update local process participant input.
input UpdateLocalProcessParticipantInput {

  # Client mutation identifier.
  clientMutationId: String

  # List of coordinators associated to the local process participant.
  coordinatorIds: [ID]

  # Local process participant description.
  description: String

  # List of directories associated to the local process participant.
  directoryIds: [ID]

  # List of groups associated to the local process participant.
  groupIds: [ID]

  # Local process participant identifier.
  id: ID!

  # Local process participant name.
  name: String

  # Local process participant type.
  type: ParticipantType

  # List of users associated to the local process participant.
  userIds: [ID]
}

# Update local process participant result.
type UpdateLocalProcessParticipantResult {

  # Client mutation identifier.
  clientMutationId: String

  # Local process participant that has been updated.
  localProcessParticipant: LocalProcessParticipant!
}

# Delete local process participant input.
input DeleteLocalProcessParticipantInput {

  # Client mutation identifier.
  clientMutationId: String

  # Local process participant identifier.
  id: ID!
}

# Delete local process participant result.
type DeleteLocalProcessParticipantResult {

  # Client mutation identifier.
  clientMutationId: String
}

# A paginated list of participants.
type ParticipantListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of participants.
  items: [Participant]
}

# A filter on participants.
input ParticipantFilter {

  # Indicates if the participant is global.
  isGlobal: Boolean
}

# A participant list order.
input ParticipantListOrder {

  # Field by which to order participants.
  field: ParticipantListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# List of possible fields to order a participant list.
enum ParticipantListOrderField {

  # Order participants by name.
  NAME

  # Order participants by type.
  TYPE
}

# A list of participant's types.
enum ParticipantType {

  # Human type participant.
  HUMAN

  # Role type participant.
  ROLE

  # Coordinator type participant.
  COORDINATOR
}

`;
