"use strict";
/**
 * process.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# A process.
type Process implements Node {

  # Process access level
  accessLevel: ProcessAccessLevel

  # Activities associated to the process.
  activities(page: Page, orderBy: ActivityListOrder, filter: ActivityFilter): ActivityListPage

  # Indicates if the user has permissions to launch a new request.
  canCreateRequest: Boolean

  # Categories associated to the process.
  categories(page: Page, orderBy: CategoryListOrder, filter: CategoryFilter): CategoryListPage

  # Data associated to the process.
  dataset(page: Page, orderBy: ProcessDataListOrder): ProcessDataListPage

  # Process description.
  description: String!

  # Process folder.
  folder: ProcessFolder

  # URL to display the graphical view of the process displayed in the portal.
  graphicalViewPortalUrl: URI

  # URL to display the graphical view of the process.
  graphicalViewUrl: URI

  # Indicates if the user has graphical view access.
  hasGraphicalViewAccess: Boolean

  # Process help information.
  help: Help

  # Process identifier.
  id: ID!

  # Indicates if the action associated data is archived when a request is closed
  isActionDataArchived: Boolean

  # Indicates if the form management is built-in
  isBuiltInForm: Boolean

  # Indicates if the file content is stored in the database
  isDatabaseStorageForFiles: Boolean

  # Indicates if the sub-process mode is enabled
  isSubProcess: Boolean

  # URL to launch a new request with the portal displayed.
  launchPortalUrl: URI

  # URL to launch a new request.
  launchUrl: URI

  # Process lead time
  leadTime: Int

  # Process lead time duration unit.
  leadTimeUnit: TimeUnit

  # Indicates if the working days/hours are used to compute the lead time
  leadTimeUseWorkingDays: Boolean

  # Process name.
  name: String!

  # Indicates if the requester is notified in a request closure
  notifyRequesterOnClosure: Boolean

  # Participant profiles associated to the process.
  participantProfiles(page: Page, filter: ProcessParticipantProfileFilter, orderBy: ProcessParticipantProfileListOrder): ProcessParticipantProfileListPage

  # Participants associated to the process.
  participants(page:Page, filter: ParticipantFilter, orderBy: ParticipantListOrder): ParticipantListPage

  # Process state.
  state: ProcessState!

  # Identifies the date and time when the process was updated.
  updatedAt: DateTime!

  # Identifies the user who updated the process.
  updatedBy: User!

  # Process version.
  version: Int!

  # Process definition in XPDL format.
  xpdl: File
}

# Create process input.
 input CreateProcessInput {

  # Process access level
  accessLevel: ProcessAccessLevel

  # Process categories
  categoryNames: [String]

  # Client mutation identifier.
  clientMutationId: String

  # Process description.
  description: String

  # Process folder identifier.
  folderId: ID

  # Process folder name.
  folderName: String

  # Process identifier used in new version creation.
  fromProcessId: ID

  # Process help information email.
  helpEmail: String

  # Process help information text.
  helpText: String

  # Process help information URL.
  helpUrl: URI

  # Indicates if the action associated data is archived when a request is closed
  isActionDataArchived: Boolean

  # Indicates if the form management is built-in
  isBuiltInForm: Boolean

  # Indicates if the file content is stored in the database
  isDatabaseStorageForFiles: Boolean

  # Indicates if the sub-process mode is enabled
  isSubProcess: Boolean

  # Process lead time
  leadTime: Int

  # Process lead time duration unit.
  leadTimeUnit: TimeUnit

  # Indicates if the working days/hours are used to compute the lead time
  leadTimeUseWorkingDays: Boolean

  # Process name.
  name: String

  # Indicates if the requester is notified in a request closure
  notifyRequesterOnClosure: Boolean

  # Process state.
  state: ProcessState
}

# Create process result.
type CreateProcessResult {
  # Client mutation identifier.
  clientMutationId: String

  # Process that has been created.
  process: Process!
}

# Create process from an XPDL definition input.
 input CreateProcessFromXpdlInput {

  # Adds new participants as global participants.
  addNewParticipantsAsGlobal: Boolean

  # Adds the current user as participant.
  addSelfToParticipant: Boolean

  # Specifies if the global participant associations are imported.
  addGlobalParticipantAssociations: Boolean

  # Client mutation identifier.
  clientMutationId: String

  # Process folder identifier.
  folderId: ID

  # Process folder name.
  folderName: String

  # Process identifier used in new version creation.
  fromProcessId: ID

  # Process name.
  name: String

  # Creates a new version if it already exists.
  newVersionIfExists: Boolean

  # Process state.
  state: ProcessState

  # Imports the process version if it is specified in the process definition.
  useVersionNumber: Boolean

  # Process definition in XPDL format.
  xpdl: FileInput
 }

 # Create process from an XPDL definition result.
type CreateProcessFromXpdlResult {

  # Client mutation identifier.
  clientMutationId: String

  # Process that has been created.
  process: Process!
}

# Update process input.
 input UpdateProcessInput {

  # Process access level
  accessLevel: ProcessAccessLevel

  # Process categories
  categories: [String]

  # Client mutation identifier.
  clientMutationId: String

  # Process description.
  description: String

  # Process folder identifier.
  folderId: ID

  # Process help information email.
  helpEmail: String

  # Process help information text.
  helpText: String

  # Process help information URL.
  helpUrl: URI

  # Process identifier
  id: ID!

  # Indicates if the action associated data is archived when a request is closed
  isActionDataArchived: Boolean

  # Indicates if the form management is built-in
  isBuiltInForm: Boolean

  # Indicates if the file content is stored in the database
  isDatabaseStorageForFiles: Boolean

  # Indicates if the sub-process mode is enabled
  isSubProcess: Boolean

  # Process lead time
  leadTime: Int

  # Process lead time duration unit.
  leadTimeUnit: TimeUnit

  # Indicates if the working days/hours are used to compute the lead time
  leadTimeUseWorkingDays: Boolean

  # Process name.
  name: String

  # Indicates if the requester is notified in a request closure
  notifyRequesterOnClosure: Boolean

  # Process state.
  state: ProcessState
}

# Update process result.
type UpdateProcessResult {

  # Client mutation identifier.
  clientMutationId: String

  # Process that has been updated.
  process: Process!
}

# Update process from an XPDL definition input.
 input UpdateProcessFromXpdlInput {

  # Adds new participants as global participants.
  addNewParticipantsAsGlobal: Boolean

  # Adds the current user as participant.
  addSelfToParticipant: Boolean

  # Specifies if the global participant associations are imported.
  addGlobalParticipantAssociations: Boolean

  # Client mutation identifier.
  clientMutationId: String

  # Process identifier.
  id: ID!

  # Imports the process version if it is specified in the process definition.
  useVersionNumber: Boolean

  # Process definition in XPDL format.
  xpdl: FileInput
 }

 # Update process from an XPDL definition result.
type UpdateProcessFromXpdlResult {

  # Client mutation identifier.
  clientMutationId: String

  # Process that has been updated.
  process: Process!
}

# Delete process input.
input DeleteProcessInput {

  # Client mutation identifier.
  clientMutationId: String

  # Process identifier.
  id: ID!
}

# Delete process result.
type DeleteProcessResult {

  # Client mutation identifier.
  clientMutationId: String
}

# A paginated list of processes.
type ProcessListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of processes.
  items: [Process]
}

# A filter on processes.
input ProcessFilter {

  # Filter processes by description.
  descriptionContains: String

  # Filter by category identifier.
  categoryId: ID

  # Filter by category name.
  categoryName: String

  # Filter by name.
  nameContains: String

  # Filter by state.
  state: ProcessState
}

# A filter on launchable processes.
input LaunchableProcessFilter {

  # Filter by category identifier.
  categoryId: ID

  # Filter by category name.
  categoryName: String

}

# A process list order.
input ProcessListOrder {

  # Field by which to order processes.
  field: ProcessListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# List of possible fields to order a process list.
enum ProcessListOrderField {

  # Order processes by name.
  NAME

  # Order processes by when they were updated.
  UPDATED_AT
}

# List possible process state.
enum ProcessState {

  # In development.
  DEV

  # In test.
  TEST

  # Active.
  ACTIVE

  # Archived.
  ARCHIVE
}

# Process access levels.
enum ProcessAccessLevel {

  # API access level.
  API

  # Private access level.
  PRIVATE

  # Public access level.
  PUBLIC
}

# Process duration time units.
enum TimeUnit {

  #Years.
  YEARS

  # Months.
  MONTHS

  # Days.
  DAYS

  # Hours.
  HOURS

  # Minutes.
  MINUTES

  # Seconds.
  SECONDS
}
`;
