"use strict";
/**
 * processfolder.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# A process folder.
type ProcessFolder implements Node {

  # Process folder description.
  description: String!

  # Process folder identifier.
  id: ID!

  # Process folder manager.
  manager: GlobalParticipant!

  # Process folder name.
  name: String!

  # List of processes associated to this process folder.
  processes (page: Page, orderBy: ProcessListOrder, filter: ProcessFolderProcessFilter): ProcessListPage
}

# A paginated list of process folders.
type ProcessFolderListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of process folders.
  items: [ProcessFolder]
}

# A filter on process folders.
input ProcessFolderFilter {

  # Filter process folders by description.
  descriptionContains: String

  # Filter process folders by name.
  nameContains: String
}

# A process folder list order.
input ProcessFolderListOrder {

  # Field by which to order categories.
  field: ProcessFolderListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# List possible fields to order a process folder list.
enum ProcessFolderListOrderField {

  # Order process folders by name.
  NAME

  # Order process folders by description.
  DESCRIPTION
}

# A filter on process folder processes.
input ProcessFolderProcessFilter {

  # Filter processes by description.
  descriptionContains: String

  # Filter processes by name.
  nameContains: String

  # Filter process by state.
  state: ProcessState
}

# Create process folder input.
input CreateProcessFolderInput {

  # Client mutation identifier.
  clientMutationId: String

  # Process folder description.
  description: String!

  # Process folder name.
  name: String!

  # Process folder manager identifier.
  managerId: ID!
}

# Create process folder result.
type CreateProcessFolderResult {

  # Client mutation identifier.
  clientMutationId: String

  # Process folder that has been created.
  processFolder: ProcessFolder!
}

# Update process folder input.
input UpdateProcessFolderInput {

  # Client mutation identifier.
  clientMutationId: String

  # Process folder description.
  description: String

  # Process folder identifier.
  id: ID!

  # Process folder name.
  name: String

  # Process folder manager identifier.
  managerId: ID
}

# Update process folder result.
type UpdateProcessFolderResult {

  # Client mutation identifier.
  clientMutationId: String

  # Process folder that has been updated.
  processFolder: ProcessFolder!
}

# Delete process folder input.
input DeleteProcessFolderInput {

  # Client mutation identifier.
  clientMutationId: String

  # Process folder identifier.
  id: ID!
}

# Delete process folder result.
type DeleteProcessFolderResult {

  # Client mutation identifier.
  clientMutationId: String
}
`;
