"use strict";
/**
 * processparticipantprofile.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# A process participant profile.
type ProcessParticipantProfile implements Node {

  # Indicates if the participant profile has permissions to access all requests.
  canAccessAllRequests: Boolean!

  # Indicates if the participant profile has permissions to cancel requests.
  canCancelRequests: Boolean!

  # Indicates if the participant profile has permissions to read comments.
  canReadComments: Boolean!

  # Indicates if the participant profile has permissions to reassign actions.
  canReassignActions: Boolean!

  # Indicates if the participant profile has permissions to view the graphical follow-up.
  canViewGraphicalFollowUp: Boolean!

  # Indicates if the participant profile has permissions to view statistics.
  canViewStatistics: Boolean!

  # Indicates if the participant profile has permissions to write comments.
  canWriteComments: Boolean!

  # Process participant profile identifier.
  id: ID!

  # Process participant profile participant.
  participant: Participant!

  # Process participant profile process.
  process: Process!

  # Process participant profile query.
  query: String

  # Process participant profile role.
  role: ProcessParticipantProfileRole!
}

# Add a process participant profile input.
input AddProcessParticipantProfileInput {

  # Indicates if the participant can access all requests.
  canAccessAllRequests: Boolean

  # Indicates if the participant can cancel requests.
  canCancelRequests: Boolean

  # Indicates if the participant can read comments.
  canReadComments: Boolean

  # Indicates if the participant can reassign an action.
  canReassignActions: Boolean

  # Indicates if the participant can view the graphical follow-up.
  canViewGraphicalFollowUp: Boolean

  # Indicates if the participant can view statistics.
  canViewStatistics: Boolean

  # Indicates if the participant can write comments.
  canWriteComments: Boolean

  # Client mutation identifier.
  clientMutationId: String

  # Process identifier.
  processId: ID!

  # Global participant identifier.
  participantId: ID!

  # Supervisor scope query
  query: String

  # Participant role
  role: ProcessParticipantProfileRole!
}

# Add a process participant profile result.
type AddProcessParticipantProfileResult {

  # Client mutation identifier.
  clientMutationId: String

  # Process participant profile that has been added.
  processParticipantProfile: ProcessParticipantProfile!
}

# Update a process participant profile input.
input UpdateProcessParticipantProfileInput {

  # Indicates if the participant can access all requests.
  canAccessAllRequests: Boolean

  # Indicates if the participant can cancel requests.
  canCancelRequests: Boolean

  # Indicates if the participant can read comments.
  canReadComments: Boolean

  # Indicates if the participant can reassign an action.
  canReassignActions: Boolean

  # Indicates if the participant can view the graphical follow-up.
  canViewGraphicalFollowUp: Boolean

  # Indicates if the participant can view statistics.
  canViewStatistics: Boolean

  # Indicates if the participant can write comments.
  canWriteComments: Boolean

  # Client mutation identifier.
  clientMutationId: String

  # Process participant profile identifier
  id: ID!

  # Supervisor scope query
  query: String

  # Participant role
  role: ProcessParticipantProfileRole
}

# Update a process participant profile result.
type UpdateProcessParticipantProfileResult {

  # Client mutation identifier.
  clientMutationId: String

  # Process participant profile that has been updated.
  processParticipantProfile: ProcessParticipantProfile!
}

# Remove a process participant profile input.
input RemoveProcessParticipantProfileInput {

  # Client mutation identifier.
  clientMutationId: String

  # Process participant profile identifier
  id: ID!
}

# Remove a process participant profile result.
type RemoveProcessParticipantProfileResult {

  # Client mutation identifier.
  clientMutationId: String
}

# A paginated list of process participant profiles.
type ProcessParticipantProfileListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of process participant profiles.
  items: [ProcessParticipantProfile]
}

# A filter on process participant profiles.
input ProcessParticipantProfileFilter {

  # Filter process participant profile by participant identifier.
  participantId: ID
}

# A process participant profile list order.
input ProcessParticipantProfileListOrder {

  # Field by which to order process participant profiles.
  field: ProcessParticipantProfileListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# List of possible fields to order a process participant profile list.
enum ProcessParticipantProfileListOrderField {

  # Order process participant profiles by name.
  NAME

  # Order process participant profiles by type.
  TYPE

  # Order process participant profiles by role.
  ROLE

  # Order process participant profiles by display order.
  DISP_ORDER
}

# A list of participant process profile' roles.
enum ProcessParticipantProfileRole {

  # Process participant profile requester role.
  REQUESTER

  # Process participant profile actor role.
  ACTOR

  # Process participant profile supervisor role.
  SUPERVISOR
}

`;
