"use strict";
/**
 * query.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# The schema allows the following query:
type Query {

  # Fetches an action by request number and action number.
  action (requestNumber: Int!, number: Int!, onBehalfOf: ID): Action

  # List of actions.
  actions (page: Page, orderBy: ActionListOrder, filter: ActionFilter, onBehalfOf: ID): ActionListPage

  # Fetches an application by its name.
  application (name: String!): Application

  # List of applications.
  applications (page: Page, orderBy: ApplicationListOrder, filter: ApplicationFilter): ApplicationListPage

  # Fetches a category by its name.
  category (name: String!, onBehalfOf: ID): Category

  # List of categories.
  categories (page: Page, orderBy: CategoryListOrder, filter: CategoryFilter, onBehalfOf: ID): CategoryListPage

  # List of delegations.
  delegations (page: Page, orderBy: DelegationListOrder, filter: DelegationFilter): DelegationListPage

  # Fetches a directory by its name.
  directory (name: String!): Directory

  # List of directories.
  directories (page: Page, orderBy: DirectoryListOrder, filter: DirectoryFilter): DirectoryListPage

  # Fetches a global list by its name.
  globalList (name: String!): GlobalList

  # List of global lists.
  globalLists (page: Page, orderBy: GlobalListListOrder, filter: GlobalListFilter): GlobalListListPage

  # Fetches a global participant by its name.
  globalParticipant (name: String!, onBehalfOf: ID): Participant

  # Fetches a group by its name.
  group (name: String!, directoryName: String!): Group

  # List of groups.
  groups (page:Page, orderBy: GroupListOrder): GroupListPage

  # Fetches a local process participant by its name, process name and process version.
  localProcessParticipant (name: String!, processName: String!, processVersion: Int!, onBehalfOf: ID): Participant

  # Fetches an object by identifier.
  node (id: ID!, onBehalfOf: ID): Node

  # Fetches a list of objects by a list of identifiers.
  nodes (ids: [ID]!, onBehalfOf: ID): [Node]

  # List of participants.
  participants (page: Page, orderBy: ParticipantListOrder, filter: ParticipantFilter, onBehalfOf: ID): ParticipantListPage

  # Fetches a process by name and version.
  process (name: String!, version: Int!, onBehalfOf: ID): Process

  # Fetches a process folder by name.
  processFolder (name: String!): ProcessFolder

  # List of processes.
  processes (page: Page,  orderBy: ProcessListOrder, filter: ProcessFilter, onBehalfOf: ID): ProcessListPage

  # List of process folders.
  processFolders (page: Page,  orderBy: ProcessFolderListOrder, filter: ProcessFolderFilter): ProcessFolderListPage

  # Fetches a request by its number.
  request (number: Int!, onBehalfOf: ID): Request

  # List of requests.
  requests (page: Page, orderBy: RequestListOrder, filter: RequestFilter, onBehalfOf: ID): RequestListPage

  # The current server.
  server: Server!

  # Fetches a user by its username.
  user (userName: String!): User

  # List of users.
  users (page: Page, orderBy: UserListOrder, filter: UserFilter): UserListPage

  # The current authenticated user.
  viewer: User
}

`;
