"use strict";
/**
 * requestdata.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# A request data.
type RequestData implements Node & WorkflowData {

  # Request data date and time value.
  dateTimeValue: DateTime

  # Request data description.
  description: String!

  # Request data file value.
  fileValue: File

  # Indicates if the request data has a value.
  hasValue: Boolean!

  # Request data identifier.
  id: ID!

  # Request data name.
  name: String!

  # Request data numeric value.
  numericValue: Float

  # Request associated to the request data.
  request: Request!

  # Request data text value.
  textValue: String

  # Request data type.
  type: WorkflowDataType!
}

# A paginated list of request data.
type RequestDataListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of request data.
  items: [RequestData]
}

# A filter on requests data.
input RequestDataFilter {

  # Filter request data by name.
  names: [String]

  # Filter request data by type.
  type: WorkflowDataType
}

# A request data list order.
input RequestDataListOrder {

  # Field by which to order request data.
  field: RequestDataListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# Lists possible fields by which to order a request data list.
enum RequestDataListOrderField {

  # Order request data by name.
  NAME

  # Order request data by type.
  TYPE

  # Order request data by display order.
  DISP_ORDER
}

# An update request dataset input.
input UpdateRequestDatasetInput {

  # Client mutation identifier.
  clientMutationId: String

  # Request identifier.
  id: ID

  # Request number.
  number: Int

  # Array of parameters.
  parameters: [ParameterInput]
}

# An update request dataset result.
type UpdateRequestDatasetResult {

  # Client mutation identifier.
  clientMutationId: String

  # Request data that have been updated.
  dataset: RequestDataListPage
}


`;
