"use strict";
/**
 * user.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# A user.
type User implements Node {

  # List of actions as participant.
  actions (page: Page, orderBy: ActionListOrder, filter: ActionFilter, onBehalfOf: ID, viewerAsMember: Boolean): ActionListPage

  # User's city.
  city: String

  # List of comments as participant.
  comments (page: Page, orderBy: CommentListOrder, onBehalfOf: ID, viewerAsMember: Boolean): CommentListPage

  # User's common name.
  commonName: String

  # User's company.
  company: String

  # User's country.
  country: String

  # User's default language.
  defaultLanguage: String!

  # User's default time zone identifier.
  defaultTimeZoneId: Int!

  # List of the user's delegable process participants.
  delegableProcessParticipants (page: Page, orderBy: DelegableProcessParticipantOrder, filter: DelegableProcessParticipantFilter): DelegableProcessParticipantListPage

  # List of delegations managed by the user.
  delegations (page: Page, orderBy: DelegationListOrder, filter: DelegationFilter): DelegationListPage

  # List of the user's delegators.
  delegators (page: Page): UserListPage

  # User's department.
  department: String

  # User's directory.
  directory: Directory

  # User's distinguished name.
  distinguishedName: String

  # User's email.
  email: String

  # User's employee number.
  employeeNumber: String

  # User's employee type.
  employeeType: String

  # User's extended attribute 1.
  extendedAttribute1: String

  # User's extended attribute 2.
  extendedAttribute2: String

  # User's extended attribute 3.
  extendedAttribute3: String

  # User's extended attribute 4.
  extendedAttribute4: String

  # User's extended attribute 5.
  extendedAttribute5: String

  # List of user's favorites
  favorites (page: Page, orderBy: FavoriteListOrder, filter: FavoriteFilter) : FavoriteListPage

  # User's fax number.
  fax: String

  # User's first name.
  firstName: String

  # List of the user's groups.
  groups (page: Page, orderBy: GroupListOrder): GroupListPage

  # User's identifier.
  id: ID!

  # User's initials.
  initials: String

  # Is the user's account active?
  isActive: Boolean!

  # Is the user an administrator?
  isAdministrator: Boolean!

  # Is the user's account archived?
  isArchived: Boolean!

  # Is the user a process folder manager?
  isProcessFolderManager: Boolean!

  # Is the user a process supervisor?
  isSupervisor: Boolean!

  # Is the user's account synchronized?
  isSynchronized: Boolean

  # Is the user the viewing user?
  isViewer: Boolean!

  # User's job title.
  jobTitle: String

  # User's preferred language.
  language: String!

  # User's last name.
  lastName: String

  # List of processes that the user can launch.
  launchableProcesses (page: Page, orderBy: ProcessListOrder, filter: LaunchableProcessFilter, onBehalfOf: ID): ProcessListPage

  # User's LDAP Active Directory path.
  ldapADsPath: String

  # User's manager.
  manager: User

  # User's mobile phone number.
  mobile: String

  # User's office.
  office: String

  # User's pager number.
  pager: String

  # List of participants as member.
  participants (page: Page, orderBy: ParticipantListOrder, filter: ParticipantFilter, onBehalfOf: ID): ParticipantListPage

  # User's personal title.
  personalTitle: String

  # User's phone number.
  phone: String

  # User's postal address.
  postalAddress: String

  # User's postal code.
  postalCode: String

  # List of processes as participant.
  processes (page: Page,  orderBy: ProcessListOrder, filter: ProcessFilter, onBehalfOf: ID): ProcessListPage

  # List of requests as participant.
  requests (page: Page, orderBy: RequestListOrder, filter: RequestFilter, onBehalfOf: ID, viewerAsMember: Boolean): RequestListPage

  # User's state.
  state: String

  # User's system identifier.
  systemIdentifier: String

  # User's preferred time zone identifier.
  timeZoneId: Int!

  # User's login name.
  userName: String!

  # List of views available to the user.
  views (page: Page, orderBy: ViewListOrder, filter: ViewFilter): ViewListPage
}

# A paginated list of users.
type UserListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # A list of users.
  items: [User]
}

# A user list order.
input UserListOrder {

  # Field by which to order users.
  field: UserListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# A list of fields by which to order a user list.
enum UserListOrderField {

  # Order users by username.
  USERNAME

  # Order users by last name.
  LASTNAME
}

# A create user input.
input CreateUserInput {

  # User's city.
  city: String

  # Client mutation identifier.
  clientMutationId: String

  # User's common name.
  commonName: String

  # User's company.
  company: String

  # User's country.
  country: String

  # User's default language.
  defaultLanguage: String

  # User's default time zone identifier.
  defaultTimeZoneId: Int

  # User's department.
  department: String

  # Directory identifier.
  directoryId: ID!

  # User's distinguished name.
  distinguishedName: String

  # User's email.
  email: String

  # User's employee number.
  employeeNumber: String

  # User's employee type.
  employeeType: String

  # User's extended attribute 1.
  extendedAttribute1: String

  # User's extended attribute 2.
  extendedAttribute2: String

  # User's extended attribute 3.
  extendedAttribute3: String

  # User's extended attribute 4.
  extendedAttribute4: String

  # User's extended attribute 5.
  extendedAttribute5: String

  # User's fax number.
  fax: String

  # User's first name.
  firstName: String

  # User's initials.
  initials: String

  # Is the user's account active?
  isActive: Boolean

  # Is the user an administrator?
  isAdministrator: Boolean

  # Is the user's account synchronized?
  isSynchronized: Boolean

  # User's job title.
  jobTitle: String

  # User's last name.
  lastName: String!

  # User's LDAP Active Directory path.
  ldapADsPath: String

  # User's manager identifier.
  managerId: ID

  # User's mobile phone number.
  mobile: String

  # User's office.
  office: String

  # User's pager number.
  pager: String

  # User's password.
  password: String

  # User's personal title.
  personalTitle: String

  # User's phone number.
  phone: String

  # User's postal address.
  postalAddress: String

  # User's postal code.
  postalCode: String

  # User's state.
  state: String

  # User's system identifier.
  systemIdentifier: String

  # User's login name.
  userName: String!
}

# A create user result.
type CreateUserResult {

  # Client mutation identifier.
  clientMutationId: String

  # User that has been created.
  user: User!
}

# An update user input.
input UpdateUserInput {

  # Client mutation identifier.
  clientMutationId: String

  # User's identifier.
  id: ID!

  # User's login name.
  userName: String

  # User's last name.
  lastName: String

  # User's first name.
  firstName: String

  # Directory identifier.
  directoryId: ID

  # Is the user an administrator?
  isAdministrator: Boolean

  # User's password.
  password: String

  # Is the user's account active?
  isActive: Boolean

  # Is the user's account synchronized?
  isSynchronized: Boolean

  # User's email.
  email: String

  # User's default language.
  defaultLanguage: String

  # User's preferred language.
  language: String

  # User's default time zone identifier.
  defaultTimeZoneId: Int

  # User's preferred time zone identifier.
  timeZoneId: Int

  # User's manager identifier.
  managerId: ID

  # User's phone number.
  phone: String

  # User's mobile phone number.
  mobile: String

  # User's fax number.
  fax: String

  # User's pager number.
  pager: String

  # User's office.
  office: String

  # User's department.
  department: String

  # User's company.
  company: String

  # User's job title.
  jobTitle: String

  # User's employee number.
  employeeNumber: String

  # User's employee type.
  employeeType: String

  # User's initials.
  initials: String

  # User's personal title.
  personalTitle: String

  # User's postal address.
  postalAddress: String

  # User's postal code.
  postalCode: String

  # User's city.
  city: String

  # User's state.
  state: String

  # User's country.
  country: String

  # User's LDAP Active Directory path.
  ldapADsPath: String

  # User's common name.
  commonName: String

  # User's distinguished name.
  distinguishedName: String

  # User's extended attribute 1.
  extendedAttribute1: String

  # User's extended attribute 2.
  extendedAttribute2: String

  # User's extended attribute 3.
  extendedAttribute3: String

  # User's extended attribute 4.
  extendedAttribute4: String

  # User's extended attribute 5.
  extendedAttribute5: String

  # User's system identifier.
  systemIdentifier: String
}

# An update user result.
type UpdateUserResult {

  # Client mutation identifier.
  clientMutationId: String

  # The user that has been updated.
  user: User!
}

# A delete user input.
input DeleteUserInput {

  # Client mutation identifier.
  clientMutationId: String

  # User's identifier.
  id: ID!
}

# A delete user result.
type DeleteUserResult {

  # Client mutation identifier.
  clientMutationId: String
}

# An add groups to user input.
input AddGroupsToUserInput {

  # Client mutation identifier.
  clientMutationId: String

  # User's identifier.
  id: ID!

  # Group IDs to be added to the user.
  groupIds: [ID]!
}

# An add groups to user result.
type AddGroupsToUserResult {

  # Client mutation identifier.
  clientMutationId: String

  # The user that has been updated.
  user: User!
}

# A remove groups from user input.
input RemoveGroupsFromUserInput {

  # Client mutation identifier.
  clientMutationId: String

  # User's identifier.
  id: ID!

  # Group IDs to be removed from the user.
  groupIds: [ID]!
}

# A remove groups from user result.
type RemoveGroupsFromUserResult {

  # Client mutation identifier.
  clientMutationId: String

  # The user that has been updated.
  user: User!
}

# A filter on users.
input UserFilter {

  # Filter by active users.
  isActive: Boolean

  # Filter by archived users.
  isArchived: Boolean

  # Filter by user's first name and last name.
  nameContains: String
}

# An update viewer preferences input.
input UpdateViewerPreferencesInput {

  # Client mutation identifier.
  clientMutationId: String

  # Viewer's preferred language.
  language: String

  # Viewer's preferred time zone identifier.
  timeZoneId: Int
}

# An update viewer preferences result.
type UpdateViewerPreferencesResult {

  # Client mutation identifier.
  clientMutationId: String

  # The user that has been updated.
  user: User!
}

# A register viewer push notification token input.
input RegisterViewerPushNotificationTokenInput {

  # Client mutation identifier.
  clientMutationId: String

  # Viewer's push notification token.
  pushNotificationToken: String!
}

# A register viewer push notification token result.
type RegisterViewerPushNotificationTokenResult {

  # Client mutation identifier.
  clientMutationId: String

  # Viewer's push notification token.
  pushNotificationToken: String!
}

# An unregister viewer push notification token input.
input UnregisterViewerPushNotificationTokenInput {

  # Client mutation identifier.
  clientMutationId: String

  # Viewer's push notification token.
  pushNotificationToken: String!
}

# An unregister viewer push notification token result.
type UnregisterViewerPushNotificationTokenResult {

  # Client mutation identifier.
  clientMutationId: String
}

`;
