"use strict";
/**
 * view.ts
 * GraphQL Type definitions using schema language
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = `

# A view.
type View implements Node {

  # View description.
  description: String!

  # URL of the view displayed in embed mode.
  embedUrl: URI!

  # View identifier.
  id: ID!

  # View URL.
  url: URI!



  # URL of the view displayed in the portal.
  portalUrl: URI!

  # Identifies the author of the view.
  author: User!

  # Identifies if the view is shared.
  isShared: Boolean!

  # Identifies if the view is displayed in the portal.
  isPortal: Boolean!
}

# A paginated list of views.
type ViewListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of views.
  items: [View]
}

# A filter on views.
input ViewFilter {

  # Indicates if the user is the author.
  asAuthor: Boolean

  # Indicates if the view is displayed in the portal.
  isPortal: Boolean

  # Indicates if the view is shared.
  isShared: Boolean
}

# A view list order.
input ViewListOrder {

  # Field by which to order views.
  field: ViewListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# List of possible fields to order a view list by.
enum ViewListOrderField {

  # Order views by description.
  DESCRIPTION
}
`;
