"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * server.ts
 * Server initialization
 */
const express_1 = __importDefault(require("express"));
const v1_1 = __importDefault(require("uuid/v1"));
const body_parser_1 = __importDefault(require("body-parser"));
const config_1 = __importDefault(require("./config"));
const logger_1 = require("./utils/logger");
const context_1 = require("./models/auth/context");
const graphqlController_1 = __importDefault(require("./controllers/graphqlController"));
require("./utils/extensions");
const config = config_1.default.getInstance();
const rootUrl = '(\/\\w+)?\/graphql';
const app = express_1.default();
logger_1.logger('INFO', 'Application NODE_ENV: ' + process.env.NODE_ENV);
logger_1.logger('INFO', 'GraphQL debug enabled: ' + config.graphql.debugEnabled);
logger_1.logger('INFO', 'GraphQL api key enabled: ' + config.graphql.apiKeyEnabled);
logger_1.logger('INFO', 'Workflow service debug enabled: ' + config.workflowService.debugEnabled);
// Authorization: a user authentication is required
app.use((req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    req.uuid = v1_1.default();
    if (!req.headers.authorization && config.graphql.apiKeyEnabled &&
        req.headers['x-wfgen-graphql-api-key'] === config.graphql.apiKey) {
        logger_1.logger('DEBUG', 'x-wfgen-graphql-api-key is valid => access authorized.');
        next();
        return;
    }
    try {
        var sub = yield context_1.authenticate(req);
    }
    catch (err) {
        logger_1.logger('ERROR', `Request ${req.uuid} Unauthorized: unable to get the authenticated username. Error: ${err}`);
        res.status(401);
        res.send('Unauthorized: Access is denied due to missing or invalid credentials.');
        return;
    }
    logger_1.logger('DEBUG', 'Request ' + req.uuid + ' Authenticate: sub: ' + sub);
    next();
}));
// Parse application/x-www-form-urlencoded
app.use(body_parser_1.default.urlencoded({
    limit: `${config.workflowService.maxInputFileContentSize + config.graphql.maxRequestBodySize}kb`,
    extended: false
}));
// Parse application/json
app.use(body_parser_1.default.json({
    limit: `${config.workflowService.maxInputFileContentSize + config.graphql.maxRequestBodySize}kb`
}));
// These statements are marked as not covered in the nyc report despite they are covered by the tests.
/* istanbul ignore next */
// Catch body content size error
app.use((err, req, res, next) => {
    if (err.type === 'entity.too.large') {
        logger_1.logger('ERROR', err.message);
        res.status(400).json({ error: err.message });
        return;
    }
    next();
});
// GraphQL API endpoints
app.use(rootUrl, graphqlController_1.default);
// Else path is never taken in tests.
/* istanbul ignore else */
if (process.env.NODE_ENV === 'test') {
    module.exports = app;
}
else {
    // Start Express Server
    app.listen(config.app.port, () => {
        logger_1.logger('INFO', 'GraphQL Server running on port ' + config.app.port);
    });
}
