"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * config.ts
 * This file contains the initialization of the configuration.
 */
const path = __importStar(require("path"));
const logger_1 = require("./utils/logger");
/**
 * Holds the configuration parameters for the application.
 * @singleton
 */
class Configuration {
    get applicationDataPath() {
        return process.env.ApplicationDataPath ||
            path.normalize(path.join(__dirname, '..', '..', 'App_Data'));
    }
    get applicationWebFormsPath() {
        return process.env.ApplicationWebFormsPath ||
            path.normalize(path.join(__dirname, '..', '..', 'WfApps', 'WebForms'));
    }
    get applicationWebConfigPath() {
        return process.env.ApplicationWebConfigPath ||
            path.normalize(path.join(__dirname, '..', '..', 'web.config'));
    }
    get applicationUrl() {
        var applicationUrl = process.env.ApplicationUrl && process.env.ApplicationUrl.endsWith('/')
            ? process.env.ApplicationUrl.substring(0, process.env.ApplicationUrl.length - 1)
            : process.env.ApplicationUrl;
        return applicationUrl;
    }
    constructor() {
        const fileUploadPath = path.join(this.applicationDataPath, 'Files', 'Hooks', 'Uploads');
        const inputFileAllowedFolders = getEnvVar('HooksInputFileAllowedFolders', '', {
            env: [
                {
                    name: 'test',
                    defaultValue: [
                        `${path.normalize(path.join(__dirname, '..', 'test'))}\\*`,
                        path.normalize(path.join(this.applicationDataPath, 'Files', 'Hooks', 'Uploads'))
                    ].join(',')
                }
            ]
        });
        const getInputFileAllowedFolders = () => {
            let allowedFolders = inputFileAllowedFolders;
            if (!allowedFolders) {
                allowedFolders = fileUploadPath;
            }
            else if (!inputFileAllowedFolders.includes(fileUploadPath)) {
                allowedFolders += `,${fileUploadPath}`;
            }
            return allowedFolders;
        };
        this.app = {
            port: getEnvVar('PORT', '8080')
        };
        this.hooks = {
            debugEnabled: getEnvVar('HooksDebugEnabled', false, {
                boolean: {
                    operator: 'eq',
                    comparisonValue: 'Y'
                },
                env: [
                    {
                        name: 'test',
                        defaultValue: true
                    }
                ]
            }),
            maxRequestBodySize: process.env.NODE_ENV === 'test' ? 200 : 100,
            maxUploadFiles: process.env.NODE_ENV === 'test' ? 3 : 30,
            fileUploadPath,
            operations: [
                'createRequest',
                'cancelRequest',
                'deleteRequest',
                'updateRequestDataset',
                'completeAction',
                'completeFormAction',
                'runScheduledSystemActions',
                'cancelAction',
                'cancelRequestActionsByName',
                'assignAction',
                'cancelActionAssignment',
                'createFavorite',
                'updateFavorite',
                'deleteFavorite',
                'addComment',
                'updateComment',
                'removeComment',
                'createApplication',
                'updateApplication',
                'deleteApplication',
                'addApplicationParameter',
                'removeApplicationParameter',
                'createCategory',
                'updateCategory',
                'deleteCategory',
                'createProcessFolder',
                'updateProcessFolder',
                'deleteProcessFolder',
                'createProcess',
                'createProcessFromXpdl',
                'updateProcess',
                'updateProcessFromXpdl',
                'deleteProcess',
                'createGlobalParticipant',
                'updateGlobalParticipant',
                'deleteGlobalParticipant',
                'addProcessParticipantProfile',
                'updateProcessParticipantProfile',
                'removeProcessParticipantProfile',
                'createLocalProcessParticipant',
                'updateLocalProcessParticipant',
                'deleteLocalProcessParticipant',
                'createGlobalList',
                'createGlobalListFromXmlDefinition',
                'updateGlobalList',
                'updateGlobalListFromXmlDefinition',
                'deleteGlobalList',
                'createUser',
                'updateUser',
                'deleteUser',
                'createGroup',
                'updateGroup',
                'deleteGroup',
                'addUsersToGroup',
                'removeUsersFromGroup',
                'addGroupsToUser',
                'removeGroupsFromUser',
                'createDelegation',
                'updateDelegation',
                'deleteDelegation'
            ],
            allowImpersonateUser: getEnvVar('HooksAllowImpersonateUser', false, {
                boolean: {
                    operator: 'eq',
                    comparisonValue: 'Y'
                }
            }),
            apiKeyEnabled: getEnvVar('HooksApiKeyEnabled', false, {
                boolean: {
                    operator: 'eq',
                    comparisonValue: 'Y'
                }
            }),
            apiKey: getEnvVar('HooksApiKey')
        };
        this.workflowService = {
            debugEnabled: getEnvVar('HooksDebugEnabled', false, {
                boolean: {
                    operator: 'eq',
                    comparisonValue: 'Y'
                },
                env: [
                    {
                        name: 'test',
                        defaultValue: true
                    }
                ]
            }),
            configFilePath: path.normalize(path.join(__dirname, '..', '..', 'web.config')),
            serviceAssemblyFilePath: path.normalize(path.join(__dirname, '..', '..', 'bin', 'Advantys.workflow.dll')),
            logHandler: (text) => logger_1.logger('DEBUG', text),
            operationTimeout: getEnvVar('HooksOperationTimeout', 30000),
            maxOperationCount: getEnvVar('HookesMaxOperationCount', 10000),
            maxInputFileSize: getEnvVar('HooksMaxInputFileSize', 10240, {
                env: [
                    {
                        name: 'test',
                        defaultValue: 400
                    }
                ]
            }),
            maxInputFileContentSize: getEnvVar('HooksMaxInputFileContentSize', 0, {
                env: [
                    {
                        name: 'test',
                        defaultValue: 1
                    }
                ]
            }),
            inputFileDownloadTimeout: getEnvVar('HooksInputFileDownloadTimeout', 100000),
            maxOperationRetries: getEnvVar('HooksMaxOperationRetries', 20),
            operationRetryDelay: getEnvVar('HooksOperationRetryDelay', 200),
            inputFileAllowedFolders: getInputFileAllowedFolders(),
            inputFileAllowedHttpUrls: getEnvVar('HooksInputFileAllowedHttpUrls', '', {
                env: [
                    {
                        name: 'test',
                        defaultValue: 'localhost:3000/*'
                    }
                ]
            }),
            maxPageSize: process.env.NODE_ENV === 'test' ? 150 : 100
        };
        if (process.env.NODE_ENV === 'test') {
            this.test = {
                testInstallScriptPath: getEnvVar('TestInstallScriptPath', path.join('C:', 'Temp')),
                applicationDataPath: this.applicationDataPath,
                applicationWebFormsPath: this.applicationWebFormsPath,
                applicationWebConfigPath: this.applicationWebConfigPath,
                retryTimes: 15,
                delay: 3000,
                databaseConnection: {
                    server: getEnvVar('TestDbServer', 'localhost'),
                    adminUser: getEnvVar('TestDbAdminUserName', 'sa'),
                    adminPassword: getEnvVar('TestDbAdminUserPassword', 'Admin2017$'),
                    user: getEnvVar('TestDbUserName', 'WFGEN_TEST_USER'),
                    password: getEnvVar('TestDbPassword', 'Admin2017$'),
                    database: getEnvVar('TestDbName', 'WFGEN_TEST'),
                    port: getEnvVar('TestDbPort', 1433)
                },
                webConfig: {
                    EngineServiceImpersonificationUsername: 'wfgen_admin',
                    ProcessesRuntimeWebServiceAllowedUsers: [
                        'wfgen_admin',
                        'user_standard',
                        'user_supervisor'
                    ].join(','),
                    EngineNotificationEnabled: 'Y',
                    PortalDisplayCodeNames: 'N',
                    PortalEnableDelegation: 'Y',
                    PortalEnableComments: 'Y',
                    ApplicationSmtpServer: '',
                    ApplicationSmtpDeliveryMethod: 'PickupDelivery',
                    ApplicationSmtpPickupDirectory: path.join('C:', 'inetpub', 'mailroot', 'Pickup'),
                    EngineNotificationDefaultSender: 'test@email.com',
                    EngineNotificationDefaultSenderName: 'John Test',
                    ApplicationSecurityPasswordSymmetricEncryptionMode: 'AES',
                    ApplicationSecurityPasswordSymmetricEncryptionKey: 'keytestkeytestkeytestkeytestkeys',
                    SendMessageApiUrl: 'http://localhost:3000',
                    EngineAllowManagerToDeleteRealProcessInstances: 'Y'
                },
                server: {}
            };
        }
    }
    static getInstance() {
        if (!this.instance) {
            this.instance = new Configuration();
        }
        return this.instance;
    }
}
exports.default = Configuration;
function getEnvVar(name, defaultValue, options) {
    const envVar = process.env[name];
    if (typeof defaultValue === 'undefined') {
        return envVar;
    }
    if (typeof envVar === 'undefined') {
        if (options && options.env) {
            const env = options.env.find(env => env.name === process.env.NODE_ENV);
            if (env) {
                return env.defaultValue;
            }
        }
        return defaultValue;
    }
    switch (typeof defaultValue) {
        case 'string':
            return envVar;
        case 'number':
            return defaultValue % 1 === 0
                ? parseInt(envVar, undefined)
                : parseFloat(envVar);
        case 'boolean':
            if (options && options.boolean) {
                switch (options.boolean.operator) {
                    case 'eq':
                        return envVar === options.boolean.comparisonValue;
                    case 'ne':
                        return envVar === options.boolean.comparisonValue;
                }
            }
            return Boolean(envVar);
    }
}
