"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * server.ts
 * Server initialization.
 */
const express_1 = __importDefault(require("express"));
const body_parser_1 = __importDefault(require("body-parser"));
const cors_1 = __importDefault(require("cors"));
const hooksController_1 = __importDefault(require("./controllers/hooksController"));
const logger_1 = require("./utils/logger");
const config_1 = __importDefault(require("./config"));
const config = config_1.default.getInstance();
const rootUrl = '(\/\\w+)?\/hooks';
const app = express_1.default();
logger_1.logger('INFO', 'Application NODE_ENV: ' + process.env.NODE_ENV);
logger_1.logger('INFO', 'Hooks debug enabled: ' + config.hooks.debugEnabled);
logger_1.logger('INFO', 'Hooks api key enabled: ' + config.hooks.apiKeyEnabled);
logger_1.logger('INFO', 'Hooks allow impersonate user: ' + config.hooks.allowImpersonateUser);
logger_1.logger('INFO', 'Workflow service debug enabled: ' + config.workflowService.debugEnabled);
// Enable Cross Origin Resource Sharing
app.use('*', cors_1.default());
// Parse application/x-www-form-urlencoded
app.use(body_parser_1.default.urlencoded({
    limit: `${config.workflowService.maxInputFileContentSize + config.hooks.maxRequestBodySize}kb`,
    extended: false
}));
// Parse application/json
app.use(body_parser_1.default.json({
    limit: `${config.workflowService.maxInputFileContentSize + config.hooks.maxRequestBodySize}kb`
}));
// Catch errors
app.use((error, req, res, next) => {
    if (error instanceof SyntaxError) {
        logger_1.logger('ERROR', 'Invalid JSON');
        res.status(400).json({ error: 'Invalid JSON.' });
        return;
    }
    if (error && error.type === 'entity.too.large') {
        logger_1.logger('ERROR', error.message);
        res.status(400).json({ error: error.message });
        return;
    }
    next();
});
// WebHooks API endpoints
app.use(rootUrl, hooksController_1.default);
// Start Express Server
app.listen(config.app.port, () => {
    logger_1.logger('INFO', 'Hooks Server running on port ' + config.app.port);
});
// App exported for testing purposes (supertest).
exports.default = app;
