"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const busboy_1 = __importDefault(require("busboy"));
const path = __importStar(require("path"));
const fs = __importStar(require("fs"));
const file_url_1 = __importDefault(require("file-url"));
const file_uri_to_path_1 = __importDefault(require("file-uri-to-path"));
const logger_1 = require("./utils/logger");
const file_1 = require("./utils/file");
function processUpload(request, response, { maxFileSize, maxFiles, fileUploadPath }) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((resolve, reject) => {
            const parser = new busboy_1.default({
                headers: request.headers,
                limits: {
                    fields: 1,
                    fileSize: maxFileSize * 1024,
                    files: maxFiles
                }
            });
            let payload;
            let uploads = [];
            parser.on('field', (fieldName, value) => {
                if (fieldName === 'payload') {
                    try {
                        payload = JSON.parse(value);
                    }
                    catch (error) {
                        reject(new Error('Invalid JSON in the payload multipart field'));
                        return;
                    }
                }
            });
            parser.on('file', (fieldname, stream, filename, _, mimetype) => __awaiter(this, void 0, void 0, function* () {
                if (!payload) {
                    reject(new Error('Misordered multipart fields: files should follow "payload"'));
                    return;
                }
                if (!payload.args.input.parameters && !payload.args.input.xpdl && !payload.args.input.xmlDefinition) {
                    reject(new Error('A parameters array, an XPDL file or an XML definition file is required.'));
                    return;
                }
                file_1.createFolderRecursive(fileUploadPath);
                let isFileMapped = false;
                if (payload.args.input.xpdl) {
                    if (payload.args.input.xpdl.uploadMap !== fieldname) {
                        reject(new Error('File missing in the request.'));
                        return;
                    }
                    const fileExtension = path.extname(filename);
                    const uploadedFilePath = path.join(fileUploadPath, `${request.uuid}${fileExtension}`);
                    payload.args.input.xpdl.url = file_url_1.default(uploadedFilePath);
                    uploads.push(new Promise((resolve, reject) => {
                        stream.on('limit', () => reject(new Error('The uploaded file has exceeded the maximum input file size limit.')));
                        stream
                            .pipe(fs.createWriteStream(uploadedFilePath))
                            .on('error', reject)
                            .on('finish', resolve);
                    }));
                }
                else if (payload.args.input.xmlDefinition) {
                    if (payload.args.input.xmlDefinition.uploadMap !== fieldname) {
                        reject(new Error('File missing in the request.'));
                        return;
                    }
                    const fileExtension = path.extname(filename);
                    const uploadedFilePath = path.join(fileUploadPath, `${request.uuid}${fileExtension}`);
                    payload.args.input.xmlDefinition.url = file_url_1.default(uploadedFilePath);
                    uploads.push(new Promise((resolve, reject) => {
                        stream.on('limit', () => reject(new Error('The uploaded file has exceeded the maximum input file size limit.')));
                        stream
                            .pipe(fs.createWriteStream(uploadedFilePath))
                            .on('error', reject)
                            .on('finish', resolve);
                    }));
                }
                else {
                    for (const param of payload.args.input.parameters) {
                        if (!param.fileValue || !param.fileValue.uploadMap || param.fileValue.uploadMap !== fieldname) {
                            continue;
                        }
                        isFileMapped = true;
                        const fileExtension = path.extname(filename);
                        const uploadedFilePath = path.join(fileUploadPath, `${request.uuid}_${fieldname}${fileExtension}`);
                        param.fileValue.url = file_url_1.default(uploadedFilePath);
                        if (!param.fileValue.name) {
                            param.fileValue.name = filename;
                        }
                        if (!param.fileValue.description) {
                            param.fileValue.description = filename;
                        }
                        if (!param.fileValue.contentType) {
                            param.fileValue.contentType = mimetype;
                        }
                        uploads.push(new Promise((resolve, reject) => {
                            stream
                                .on('limit', () => reject(new Error('The uploaded file has exceeded the maximum input file size limit.')));
                            stream
                                .pipe(fs.createWriteStream(uploadedFilePath))
                                .on('error', reject)
                                .on('finish', resolve);
                        }));
                        break;
                    }
                }
                // If a file is attached but no uploadMap has been defined
                if (!isFileMapped && payload.args.input.parameters) {
                    try {
                        deleteTemporaryFiles(payload.args.input.parameters);
                    }
                    catch (e) {
                        logger_1.logger('ERROR', 'Request ' + request.uuid + ' ' + e.message);
                    }
                    reject(new Error('File missing in the request.'));
                    return;
                }
            }));
            parser.once('filesLimit', () => reject(new Error('The file uploads limit has been exceeded.')));
            parser.once('finish', () => __awaiter(this, void 0, void 0, function* () {
                request.unpipe(parser);
                request.resume();
                if (!payload) {
                    reject(new Error('Missing multipart field "payload"'));
                    return;
                }
                try {
                    yield Promise.all(uploads);
                }
                catch (e) {
                    if (payload.args.input.parameters) {
                        try {
                            deleteTemporaryFiles(payload.args.input.parameters);
                        }
                        catch (deleteFileExc) {
                            logger_1.logger('ERROR', 'Request ' + request.uuid + ' ' + deleteFileExc.message);
                        }
                    }
                    else if (payload.args.input.xpdl) {
                        try {
                            deleteTemporaryFile(payload.args.input.xpdl.url);
                        }
                        catch (deleteFileExc) {
                            logger_1.logger('ERROR', 'Request ' + request.uuid + ' ' + deleteFileExc.message);
                        }
                    }
                    else {
                        try {
                            deleteTemporaryFile(payload.args.input.xmlDefinition.url);
                        }
                        catch (deleteFileExc) {
                            logger_1.logger('ERROR', 'Request ' + request.uuid + ' ' + deleteFileExc.message);
                        }
                    }
                    reject(e);
                    return;
                }
                if (payload.args.input.xpdl && payload.args.input.xpdl.uploadMap && !payload.args.input.xpdl.url || payload.args.input.xmlDefinition && payload.args.input.xmlDefinition.uploadMap && !payload.args.input.xmlDefinition.url) {
                    reject(new Error('File missing in the request.'));
                    return;
                }
                else if (payload.args.input.parameters) {
                    payload.args.input.parameters
                        .filter((fileParam) => fileParam.fileValue)
                        .forEach((parameter) => {
                        if (parameter.fileValue.uploadMap &&
                            parameter.fileValue.url &&
                            fs.existsSync(file_uri_to_path_1.default(parameter.fileValue.url))) {
                            parameter.fileValue.size = fs.statSync(file_uri_to_path_1.default(parameter.fileValue.url)).size;
                        }
                        // If an uploadMap is defined but the corresponding file has not been attached
                        if (parameter.fileValue.uploadMap && !parameter.fileValue.url) {
                            try {
                                deleteTemporaryFiles(payload.args.input.parameters);
                            }
                            catch (e) {
                                logger_1.logger('ERROR', 'Request ' + request.uuid + ' ' + e.message);
                            }
                            reject(new Error('File missing in the request.'));
                            return;
                        }
                    });
                }
                resolve(payload);
            }));
            request.pipe(parser);
        });
    });
}
exports.processUpload = processUpload;
function deleteTemporaryFiles(parameters) {
    console.log(parameters);
    parameters.forEach((param) => {
        if (!param.fileValue || !param.fileValue.uploadMap || !param.fileValue.url) {
            return;
        }
        deleteTemporaryFile(param.fileValue.url);
    });
}
exports.deleteTemporaryFiles = deleteTemporaryFiles;
function deleteTemporaryFile(filePath) {
    const path = file_uri_to_path_1.default(filePath);
    if (!fs.existsSync(path)) {
        return;
    }
    try {
        fs.unlinkSync(path);
    }
    catch (_) {
        logger_1.logger('ERROR', `Unexpected error during file upload management. Temporary file ${path} deletion has failed.`);
    }
}
exports.deleteTemporaryFile = deleteTemporaryFile;
