"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * config.ts
 * Contains the definition of the configuration.
 */
const path = __importStar(require("path"));
const altlogger_1 = require("./utils/altlogger");
/**
 * @singleton
 */
class Configuration {
    get applicationUrl() {
        const applicationUrl = process.env.ApplicationUrl && process.env.ApplicationUrl.endsWith('/')
            ? process.env.ApplicationUrl.substring(0, process.env.ApplicationUrl.length - 1)
            : process.env.ApplicationUrl;
        if (!applicationUrl) {
            throw new Error('"ApplicationUrl" is not defined.');
        }
        return applicationUrl;
    }
    get applicationDataPath() {
        return process.env.ApplicationDataPath ||
            path.normalize(path.join(__dirname, '..', '..', 'App_Data'));
    }
    constructor() {
        this.app = {
            port: process.env.PORT || 8080,
            dataPath: this.applicationDataPath,
            logsPath: path.join(this.applicationDataPath, 'logFiles', 'dir', 'synchro'),
            cacheEnabled: true,
            cacheMaxAge: 5
        };
        this.workflowService = {
            debugEnabled: process.env.ScimDebugEnabled
                ? process.env.ScimDebugEnabled === 'Y'
                : false,
            configFilePath: process.env.ScimWfgenConfigFilePath
                ? path.normalize(process.env.ScimWfgenConfigFilePath)
                : path.normalize(path.join(__dirname, '..', '..', 'web.config')),
            serviceAssemblyFilePath: process.env.ScimWfgenAssemblyFilePath
                ? path.normalize(process.env.ScimWfgenAssemblyFilePath)
                : path.normalize(path.join(__dirname, '..', '..', 'bin', 'Advantys.workflow.dll')),
            logHandler: (text) => altlogger_1.logger.console.debug(text),
            operationTimeout: process.env.ScimOperationTimeout
                ? parseInt(process.env.ScimOperationTimeout, undefined)
                : 30000,
            maxOperationCount: process.env.ScimMaxOperationCount
                ? parseInt(process.env.ScimMaxOperationCount, undefined)
                : 10000,
            maxInputFileSize: process.env.ScimMaxInputFileSize
                ? parseInt(process.env.ScimMaxInputFileSize, undefined)
                : 10240,
            inputFileDownloadTimeout: process.env.ScimInputFileDownloadTimeout
                ? parseInt(process.env.ScimInputFileDownloadTimeout, undefined)
                : 100000,
            maxOperationRetries: process.env.ScimMaxOperationRetries
                ? parseInt(process.env.ScimMaxOperationRetries, undefined)
                : 20,
            operationRetryDelay: process.env.ScimOperationRetryDelay
                ? parseInt(process.env.ScimOperationRetryDelay, undefined)
                : 200
        };
        if (process.env.NODE_ENV === 'test') {
            this.test = {
                runMode: process.env.ScimTestRunMode || 'app',
                endpoints: {
                    users: process.env.ScimTestUsersEndpoint || '/wfgen/scim/Users',
                    groups: process.env.ScimTestGroupsEndpoint || '/wfgen/scim/Groups'
                }
            };
        }
    }
    static getInstance() {
        if (!Configuration.instance) {
            Configuration.instance = new Configuration();
        }
        return Configuration.instance;
    }
}
exports.default = Configuration;
