"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * groups.ts
 * Controller for the /Groups endpoint.
 */
const express = __importStar(require("express"));
const constants_1 = __importDefault(require("../models/constants"));
const error_1 = __importDefault(require("../models/helpers/error"));
const directory_1 = __importDefault(require("../models/directory"));
const search_1 = require("../models/search");
const PatchOperations = __importStar(require("../models/patchoperations"));
const logger_1 = require("../models/helpers/logger");
const router = express.Router();
/**
 * GET /Groups
 * Performs a search through a GET request.
 */
router.get('/', (req, res) => __awaiter(this, void 0, void 0, function* () {
    const directory = new directory_1.default(req.getBaseUrl(), req.authToken);
    const attributes = req.query.attributes;
    const excludedAttributes = req.query.excludedAttributes;
    logger_1.logToFile("GROUP" /* Group */, directory, 'Search groups with filter: %s', req.query.filter);
    try {
        var results = yield directory.search(constants_1.default.schemas.group, req.query.filter, req.query.sortBy, req.query.sortOrder ? req.query.sortOrder.toLocaleLowerCase() : null, req.query.startIndex, req.query.count, !attributes || attributes instanceof Array
            ? attributes : attributes.split(','), !excludedAttributes || excludedAttributes instanceof Array
            ? excludedAttributes : excludedAttributes.split(','));
    }
    catch (err) {
        if (err instanceof search_1.InvalidFilterError) {
            logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Invalid filter %s', req.query.filter);
            error_1.default.sendInvalidFilterError(res);
            return;
        }
        if (err instanceof search_1.InvalidSortOrderError) {
            logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Invalid sort order provided (%s)', req.query.sortOrder);
            error_1.default.sendInvalidValue(res, err.message);
            return;
        }
        if (err instanceof search_1.InvalidCountError) {
            logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Invalid count provided (%s)', req.query.count);
            error_1.default.sendInvalidValue(res, err.message);
            return;
        }
        if (err.statusCode) {
            error_1.default.handleWorkflowServiceErrors(err, res, "GROUP/ERROR" /* GroupError */, directory);
            return;
        }
        logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Unexpected error: %s (filter: %s)', err.message, req.params.filter);
        error_1.default.sendInternalServerError(res, err.message);
        return;
    }
    logger_1.logToFile("GROUP" /* Group */, directory, 'Search groups: completed (filter: %s)', req.query.filter);
    res.status(200).json({
        schemas: [constants_1.default.schemas.listResponse],
        Resources: results,
        totalResults: results.length,
        itemsPerPage: req.query.count > 0 ? req.query.count : results.length,
        startIndex: req.query.startIndex
    });
}));
/**
 * GET /Groups/:groupId
 * Gets the group associated with {groupId}.
 * @param {String} groupId The id of the group.
 */
router.get('/:groupId', (req, res) => __awaiter(this, void 0, void 0, function* () {
    const groupId = req.params.groupId;
    const attributes = 'attributes' in req.query
        ? req.query.attributes.split(',') : null;
    const excludedAttributes = 'excludedAttributes' in req.query
        ? req.query.excludedAttributes.split(',') : null;
    const baseUrl = req.getBaseUrl();
    const directory = new directory_1.default(baseUrl, req.authToken);
    logger_1.logToFile("GROUP" /* Group */, directory, 'GET Group: %s', groupId);
    try {
        var repr = yield directory.getGroup(groupId, attributes, excludedAttributes);
    }
    catch (err) {
        if (err.statusCode) {
            error_1.default.handleWorkflowServiceErrors(err, res, "GROUP/ERROR" /* GroupError */, directory);
            return;
        }
        logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, `Unexpected error: ${(err && err.message) || 'no message'} (groupId: %s)`, groupId);
        error_1.default.sendInternalServerError(res);
        return;
    }
    logger_1.logToFile("GROUP" /* Group */, directory, 'GET Group: completed (groupId: %s)', groupId);
    res.location((repr.meta && repr.meta.location) || baseUrl);
    res.status(200).json(repr);
}));
/**
 * DELETE /Groups/:groupId
 * Deletes a group associated with {groupId}
 * @param {String} groupId The id of the group.
 */
router.delete('/:groupId', (req, res) => __awaiter(this, void 0, void 0, function* () {
    const groupId = req.params.groupId;
    const baseUrl = req.getBaseUrl();
    const directory = new directory_1.default(baseUrl, req.authToken);
    logger_1.logToFile("GROUP/DELETE" /* GroupDelete */, directory, 'DELETE Group (groupId: %s)', groupId);
    try {
        yield directory.deleteGroup(groupId);
    }
    catch (err) {
        if (err.statusCode) {
            error_1.default.handleWorkflowServiceErrors(err, res, "GROUP/ERROR" /* GroupError */, directory);
            return;
        }
        logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Unexpected error: %s (groupId: %s)', err.message, groupId);
        error_1.default.sendInternalServerError(res, err.message);
        return;
    }
    logger_1.logToFile("GROUP/DELETE" /* GroupDelete */, directory, 'DELETE Group: completed (groupId: %s)', groupId);
    res.sendStatus(204);
}));
/**
 * POST /Groups/
 * Creates a group.
 */
router.post('/', (req, res) => __awaiter(this, void 0, void 0, function* () {
    const baseUrl = req.getBaseUrl();
    const directory = new directory_1.default(baseUrl, req.authToken);
    logger_1.logToFile("GROUP/ADD" /* GroupAdd */, directory, 'POST Group (displayName: %s)', req.body.displayName);
    if (!req.body.schemas ||
        !req.body.schemas.includes(constants_1.default.schemas.group) ||
        !req.body.displayName ||
        req.body.displayName === '') {
        logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Invalid syntax (displayName: %s)', req.body.displayName);
        error_1.default.sendInvalidSyntax(res);
        return;
    }
    try {
        var repr = yield directory.createGroup(req.body);
    }
    catch (err) {
        if (err.statusCode) {
            error_1.default.handleWorkflowServiceErrors(err, res, "GROUP/ERROR" /* GroupError */, directory);
        }
        else {
            logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Unexpected error (displayName: %s)', req.body.displayName);
            error_1.default.sendInternalServerError(res, err);
        }
        return;
    }
    logger_1.logToFile("GROUP/ADD" /* GroupAdd */, directory, 'POST Group: completed (displayName: %s)', req.body.displayName);
    res.location(repr.meta.location);
    res.status(201).json(repr);
}));
/**
 * PATCH /Groups/:groupId
 * Partially modifies a group associated with {groupId}.
 * @param {String} groupId The id of the group.
 */
router.patch('/:groupId', (req, res) => __awaiter(this, void 0, void 0, function* () {
    const baseUrl = req.getBaseUrl();
    const directory = new directory_1.default(baseUrl, req.authToken);
    logger_1.logToFile("GROUP/UPDATE" /* GroupUpdate */, directory, 'PATCH Group (groupId: %s)', req.params.groupId);
    if (!req.body.schemas ||
        !req.body.schemas.includes(constants_1.default.schemas.patchOperation)) {
        logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Incorrect schema (groupId: %s)', req.params.groupId);
        error_1.default.sendIncorrectSchema(res);
        return;
    }
    if (!req.body.Operations ||
        !(req.body.Operations instanceof Array) ||
        req.body.Operations.length <= 0) {
        logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Missing patch operations (groupId: %s)', req.params.groupId);
        error_1.default.sendPatchOperationsMissing(res);
        return;
    }
    try {
        var repr = yield directory.partialUpdateGroup(req.params.groupId, req.body.Operations);
    }
    catch (err) {
        if (err instanceof PatchOperations.PatchImmutableError) {
            logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Tried to modify an immutable value (groupId: %s)', req.params.groupId);
            error_1.default.sendImmutablePatchError(res);
        }
        else if (err instanceof PatchOperations.PatchNoPathError) {
            logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Missing path (groupId: %s)', req.params.groupId);
            error_1.default.sendNoPath(res);
        }
        else if (err instanceof PatchOperations.PatchNoValueError) {
            logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'No value provided (groupId: %s)', req.params.groupId);
            error_1.default.sendNoValue(res);
        }
        else if (err instanceof PatchOperations.PatchOpMissingError) {
            logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'No operations provided (groupId: %s)', req.params.groupId);
            error_1.default.sendPatchOperationsMissing(res);
        }
        else if (err instanceof PatchOperations.PatchInvalidFilterError) {
            logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Invalid filter (groupId: %s)', req.params.groupId);
            error_1.default.sendInvalidFilterError(res);
        }
        else if (err instanceof PatchOperations.PatchNoTargetError) {
            logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Not target provided (groupId: %s)', req.params.groupId);
            error_1.default.sendNoPathReplace(res);
        }
        else if (err instanceof PatchOperations.PatchRemoveComplexAttributeError) {
            logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Tried to remove a complexe attribute (groupId: %s)', req.params.groupId);
            error_1.default.sendPatchRemoveComplexAttributeError(res);
        }
        else if (err.statusCode) {
            error_1.default.handleWorkflowServiceErrors(err, res, "GROUP/ERROR" /* GroupError */, directory);
        }
        else {
            logger_1.logToFile("GROUP/ERROR" /* GroupError */, directory, 'Unexpected error: %s (groupId: %s)', err.message, req.params.groupId);
            error_1.default.sendInternalServerError(res);
        }
        return;
    }
    logger_1.logToFile("GROUP/UPDATE" /* GroupUpdate */, directory, 'PATCH Group: completed (groupId: %s)', req.params.groupId);
    res.location(repr.meta.location);
    res.status(200).json(repr);
}));
exports.default = router;
