"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * user.ts
 * Controller for the /user endpoint.
 */
const express = __importStar(require("express"));
const error_1 = __importDefault(require("../models/helpers/error"));
const constants_1 = __importDefault(require("../models/constants"));
const PatchOperations = __importStar(require("../models/patchoperations"));
const search_1 = require("../models/search");
const directory_1 = __importDefault(require("../models/directory"));
const logger_1 = require("../models/helpers/logger");
const router = express.Router();
/**
 * GET /Users
 * Performs a search through a GET request.
 */
router.get('/', (req, res) => __awaiter(this, void 0, void 0, function* () {
    const directory = new directory_1.default(req.getBaseUrl(), req.authToken);
    const attributes = req.query.attributes;
    const excludedAttributes = req.query.excludedAttributes;
    logger_1.logToFile("USER" /* User */, directory, 'Search operation with filter: %s', req.query.filter);
    try {
        var results = yield directory.search(constants_1.default.schemas.user, req.query.filter, req.query.sortBy, req.query.sortOrder ? req.query.sortOrder.toLocaleLowerCase() : null, req.query.startIndex, req.query.count, !attributes || attributes instanceof Array
            ? attributes : attributes.split(','), !excludedAttributes || excludedAttributes instanceof Array
            ? excludedAttributes : excludedAttributes.split(',') // eslint-disable-line
        );
    }
    catch (err) {
        if (err instanceof search_1.InvalidFilterError) {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Invalid filter: %s', req.query.filter);
            error_1.default.sendInvalidFilterError(res);
            return;
        }
        if (err instanceof search_1.InvalidSortOrderError) {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Invalid sort order: %s', req.query.sortOrder);
            error_1.default.sendInvalidValue(res, err.message);
            return;
        }
        if (err instanceof search_1.InvalidCountError) {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Invalid count: %s', req.query.count);
            error_1.default.sendInvalidValue(res, err.message);
            return;
        }
        if (err instanceof search_1.TooManyResultsError) {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Too many results');
            error_1.default.sendTooManyQueryResults(res);
            return;
        }
        if (err.statusCode) {
            error_1.default.handleWorkflowServiceErrors(err, res, "USER/ERROR" /* UserError */, directory);
            return;
        }
        logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Unexpected error: %s', err.message);
        error_1.default.sendInternalServerError(res, err.message);
        return;
    }
    logger_1.logToFile("USER" /* User */, directory, 'Search operation with filter (%s): completed', req.query.filter);
    res.status(200).json({
        schemas: [constants_1.default.schemas.listResponse],
        Resources: results,
        totalResults: results.length,
        itemsPerPage: req.query.count > 0 ? req.query.count : results.length,
        startIndex: req.query.startIndex
    });
}));
/**
 * GET /Users/:userId
 * Get the user associated with {userId}.
 * @param {String} userId The id of the user.
 */
router.get('/:userId', (req, res) => __awaiter(this, void 0, void 0, function* () {
    const userId = req.params.userId;
    const attributes = 'attributes' in req.query
        ? req.query.attributes.split(',') : null;
    const excludedAttributes = 'excludedAttributes' in req.query
        ? req.query.excludedAttributes.split(',') : null;
    const baseUrl = req.getBaseUrl();
    const directory = new directory_1.default(baseUrl, req.authToken);
    logger_1.logToFile("USER" /* User */, directory, 'GET user with id %s', userId);
    // tslint:disable-next-line: strict-type-predicates
    if (typeof userId === 'undefined' || userId === '') {
        logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'User id missing');
        error_1.default.sendIdMissing(res);
        return;
    }
    try {
        var repr = yield directory.getUser(userId, attributes, excludedAttributes);
    }
    catch (err) {
        if (err.statusCode) {
            error_1.default.handleWorkflowServiceErrors(err, res, "USER/ERROR" /* UserError */, directory);
            return;
        }
        logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Unexpected error: %s (User %s)', err.message, userId);
        error_1.default.sendInternalServerError(res);
        return;
    }
    logger_1.logToFile("USER" /* User */, directory, 'GET user with id %s: completed', userId);
    res.location(repr.meta && repr.meta.location ? repr.meta.location : baseUrl);
    res.status(200).json(repr);
}));
/**
 * POST /Users/
 * Creates a user.
 */
router.post('/', (req, res) => __awaiter(this, void 0, void 0, function* () {
    const hasFamilyName = typeof req.body.name === 'object'
        ? req.body.name.familyName : req.body.name;
    const baseUrl = req.getBaseUrl();
    const directory = new directory_1.default(baseUrl, req.authToken);
    logger_1.logToFile("USER/ADD" /* UserAdd */, directory, 'POST user (userName: %s)', req.body.userName);
    if (!req.body.schemas ||
        !req.body.schemas.includes(constants_1.default.schemas.user) ||
        !req.body.userName ||
        req.body.userName === '' ||
        !hasFamilyName) {
        logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Invalid syntax, (userName: %s)', req.body.userName);
        error_1.default.sendInvalidSyntax(res);
        return;
    }
    try {
        var repr = yield directory.createUser(req.body);
    }
    catch (err) {
        if (err === constants_1.default.scimTypes.uniqueness) {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'User already exists for userName: %s', req.body.userName);
            error_1.default.sendUniquenessError(res);
        }
        else if (err.statusCode) {
            error_1.default.handleWorkflowServiceErrors(err, res, "USER/ERROR" /* UserError */, directory);
        }
        else {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Unexpected error: %s (userName: %s)', err.message, req.body.userName);
            error_1.default.sendInternalServerError(res, err);
        }
        return;
    }
    logger_1.logToFile("USER/ADD" /* UserAdd */, directory, 'POST user: completed (userName: %s)', req.body.userName);
    res.location(repr.meta.location);
    res.status(201).json(repr);
}));
/**
 * PATCH /Users/:userId
 * Modifies part of the user associated with {userId}.
 * @param {userId} the id of the user.
 */
router.patch('/:userId', (req, res) => __awaiter(this, void 0, void 0, function* () {
    const baseUrl = req.getBaseUrl();
    const directory = new directory_1.default(baseUrl, req.authToken);
    logger_1.logToFile("USER/UPDATE" /* UserUpdate */, directory, 'PATCH user: %s', req.params.userId);
    if (!req.body.schemas ||
        !req.body.schemas.includes(constants_1.default.schemas.patchOperation)) {
        logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Incorrect schema (userId: %s)', req.params.userId);
        error_1.default.sendIncorrectSchema(res);
        return;
    }
    else if (!req.body.Operations ||
        !(req.body.Operations instanceof Array) ||
        req.body.Operations.length <= 0) {
        logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Missing operations to execute');
        error_1.default.sendPatchOperationsMissing(res);
        return;
    }
    try {
        var repr = yield directory.partialUpdateUser(req.params.userId, req.body.Operations);
    }
    catch (err) {
        if (err === 'uniqueness' ||
            (err.statusCode === 500 &&
                err.message.indexOf('already in use') !== -1)) {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Value already in use (user %s)', req.params.userId);
            error_1.default.sendUniquenessError(res);
        }
        else if (err instanceof PatchOperations.PatchImmutableError) {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Value is immutable (user %s)', req.params.userId);
            error_1.default.sendImmutablePatchError(res);
        }
        else if (err instanceof PatchOperations.PatchNoPathError) {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Path is missing (user %s)', req.params.userId);
            error_1.default.sendNoPath(res);
        }
        else if (err instanceof PatchOperations.PatchNoValueError) {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'No value provided (userId: %s)', req.params.userId);
            error_1.default.sendNoValue(res);
        }
        else if (err instanceof PatchOperations.PatchOpMissingError) {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Missing operations (userId: %s)', req.params.userId);
            error_1.default.sendPatchOperationsMissing(res);
        }
        else if (err instanceof PatchOperations.PatchInvalidFilterError) {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Invalid filter (userId: %s)', req.params.userId);
            error_1.default.sendInvalidFilterError(res);
        }
        else if (err instanceof PatchOperations.PatchNoTargetError) {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'No path provided (userId: %s)', req.params.userId);
            error_1.default.sendNoPathReplace(res);
        }
        else if (err instanceof PatchOperations.PatchRemoveComplexAttributeError) {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Tried to remove an attribute with complex filter (userId: %s)', req.params.userId);
            error_1.default.sendPatchRemoveComplexAttributeError(res);
        }
        else if (err.statusCode) {
            error_1.default.handleWorkflowServiceErrors(err, res, "USER/ERROR" /* UserError */, directory);
        }
        else {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Unexpected error: %s (userId: %s)', err.message, req.params.userId);
            error_1.default.sendInternalServerError(res);
        }
        return;
    }
    logger_1.logToFile("USER/UPDATE" /* UserUpdate */, directory, 'PATCH user: completed (userId: %s)', req.params.userId);
    res.location(repr.meta.location);
    res.status(200).json(repr);
}));
/**
 * DELETE /Users/:userId
 * Deletes the user associated with {userId}.
 * @param {string} userId the id of the user.
 */
router.delete('/:userId', (req, res) => __awaiter(this, void 0, void 0, function* () {
    const userId = req.params.userId;
    const baseUrl = req.getBaseUrl();
    const directory = new directory_1.default(baseUrl, req.authToken);
    logger_1.logToFile("USER/DELETE" /* UserDelete */, directory, 'DELETE user (userId: %s)', userId);
    // tslint:disable-next-line: strict-type-predicates
    if (typeof userId === 'undefined' || userId === '') {
        logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Id missing');
        error_1.default.sendIdMissing(res);
        return;
    }
    try {
        yield directory.deleteUser(userId);
    }
    catch (err) {
        if (err.statusCode) {
            error_1.default.handleWorkflowServiceErrors(err, res, "USER/ERROR" /* UserError */, directory);
        }
        else {
            logger_1.logToFile("USER/ERROR" /* UserError */, directory, 'Unexpected error: %s (userId: %s)', err.message, userId);
            error_1.default.sendInternalServerError(res, err);
        }
        return;
    }
    logger_1.logToFile("USER/DELETE" /* UserDelete */, directory, 'DELETE user: completed (userId: %s)', userId);
    res.sendStatus(204);
}));
exports.default = router;
