"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * filter.ts
 * Contains the definition of the Filter class.
 */
const lexer_1 = __importDefault(require("../utils/filter/lexer"));
const parser_1 = __importDefault(require("../utils/filter/parser"));
const Expressions = __importStar(require("../utils/filter/expressions"));
/**
 * Represents a SCIM filter
 */
class Filter {
    /**
     * Instanciates a Filter.
     * @param filterString A raw string containing the filter.
     */
    constructor(filterString) {
        this.filterString = filterString;
        const expression = new parser_1.default(new lexer_1.default(filterString)).parse();
        if (!expression) {
            throw new Error('Unable to parse the filter.');
        }
        this.expressionTree = expression;
    }
    /**
     * Tests an object to know if the filter is applicable.
     * @param obj An object to test.
     * @return `true` if the filter can be applied. `false` otherwise.
     */
    test(obj) {
        return this.expressionTree.apply(obj);
    }
    /**
     * Parses the AST to obtain a basic javascript object that can be used by the application.
     * Note that this function is very basic and doesn't get very far into the
     * parsing of the filter. It doesn't support OR expressions yet as well.
     *
     * @param tree An AST representing the filter.
     * @return A basic object that says which properties should be applied for filtering.
     */
    getJavaScriptObject(tree = undefined) {
        if (!tree) {
            tree = this.expressionTree;
        }
        // TODO: Make it recursive.
        if (tree instanceof Expressions.SimpleExpression && tree.operator === 'EQ') {
            return {
                [tree.left]: tree.right
            };
        }
        else if (tree instanceof Expressions.CompoundExpression) {
            let obj = Object.assign({}, this.getJavaScriptObject(tree.left));
            obj = Object.assign(obj, this.getJavaScriptObject(tree.right));
            return obj;
        }
    }
}
exports.default = Filter;
