"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * group.ts
 * Definition of a group resource.
 */
const constants_1 = __importDefault(require("../models/constants"));
const resource_1 = require("./resource");
const user_1 = require("./user");
/**
 * Represents a group resource.
 */
class GroupResource extends resource_1.Resource {
    /**
     * Creates an instance of GroupResource.
     */
    constructor(obj = undefined) {
        super('Group', obj);
        this.schemas = [constants_1.default.schemas.group];
        this.requiredAttributes.push('displayName');
        if (obj) {
            this.displayName = obj.displayName;
            this.members = obj.members;
        }
    }
    /**
     * Adds the full url location to the representation.
     * @param baseUrl The base url of the resource.
     */
    addUrlLocation(baseUrl) {
        this.meta.location = `${baseUrl}/${this.id}`;
        if (this.members) {
            this.members.forEach((member) => {
                if (typeof member !== 'string' && !(member instanceof user_1.UserResource)) {
                    member.$ref = `${baseUrl.replace('Groups', 'Users')}/${member.value}`;
                }
            });
        }
    }
    static validate(obj) {
        const superValidated = super.validate(obj);
        if (!superValidated) {
            return false;
        }
        return 'displayName' in obj &&
            'members' in obj;
    }
}
exports.GroupResource = GroupResource;
/**
 * Represents a WorkflowGen Group.
 * @class WFGGroup
 */
class WFGGroup extends resource_1.WFGResource {
    constructor(id, name) {
        super(id);
        this.name = name;
        this.users = [];
    }
    static validate(obj) {
        const superValidated = super.validate(obj);
        if (!superValidated) {
            return false;
        }
        return 'name' in obj;
    }
}
exports.WFGGroup = WFGGroup;
