"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * grouptranslator.ts
 * Contains the definition of the GroupTranslator class.
 */
const translator_1 = __importDefault(require("./translator"));
const group_1 = require("../group");
const user_1 = require("../user");
const usertranslator_1 = __importDefault(require("./usertranslator"));
/**
 * Concrete Group translator.
 */
class GroupTranslator extends translator_1.default {
    getSCIMAttributesMap() {
        return new Map([
            ['id', 'id'],
            ['displayName', 'name'],
            ['members', 'users'],
            ['externalId', 'systemIdentifier']
        ]);
    }
    translateToWFG(object) {
        let group = new group_1.WFGGroup(object.id, object.displayName);
        group.systemIdentifier = object.externalId;
        if (object.members) {
            // TODO: Better translation with correct member items.
            // This instruction can be safer by adding deeper type checking. This is
            // kept simple for the purpose of the migration.
            group.users = object.members
                .filter(m => user_1.UserResource.validate(m))
                .map((m) => new usertranslator_1.default(m).translate());
        }
        Object.cleanProperties(group, false);
        return group;
    }
    translateToSCIM(object) {
        let group = new group_1.GroupResource();
        group.id = object.id;
        group.displayName = object.name;
        group.externalId = object.systemIdentifier;
        if (object.users) {
            // TODO: Better translation with correct member items.
            group.members = object.users.map(u => new usertranslator_1.default(u).translate());
        }
        Object.cleanProperties(group, false);
        return group;
    }
    isSCIM(obj) {
        return group_1.GroupResource.validate(obj);
    }
    isWFG(obj) {
        return group_1.WFGGroup.validate(obj);
    }
}
exports.default = GroupTranslator;
