"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Abstract class for concrete translators.
 */
class Translator {
    /**
     * Instanciates a new Translator.
     * @param type The type of translation to do. e.g. the direction of the translation.
     * @param object The object to translate.
     */
    constructor(object) {
        this.object = object;
    }
    /**
     * Translate the object passed in the constructor.
     * @return The translated object. `null` if no object was provided in the constructor.
     * @throws {Error} Thrown when the object could not be translated.
     */
    translate() {
        if (!this.object) {
            throw new Error('The object to translate is null or undefined.');
        }
        if (this.isSCIM(this.object)) {
            return this.translateToWFG(this.object);
        }
        else if (this.isWFG(this.object)) {
            return this.translateToSCIM(this.object);
        }
        throw new Error('Could not translate the object.');
    }
    /**
     * Translates an attribute name into its translated conterpart.
     * @param attr The name of the attribute to translate.
     * @return A tuple containing the scim and wfg property translated respectively.
     */
    translateAttribute(attr) {
        const tuple = [undefined, undefined];
        for (const [key, value] of this.getSCIMAttributesMap().entries()) {
            if (key === attr) {
                tuple[1] = value;
            }
            if (value === attr) {
                tuple[0] = key;
            }
        }
        return tuple;
    }
}
exports.default = Translator;
